@@ -4,8 +4,7 @@
 # Copyright (C) 2010 Radim Rehurek <radimrehurek@seznam.cz>
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
 
-
-"""This module implements the concept of Dictionary -- a mapping between words and their integer ids."""
+"""This module implements the concept of a Dictionary -- a mapping between words and their integer ids."""
 
 from __future__ import with_statement
 
@@ -30,20 +29,23 @@ logger = logging.getLogger(__name__)
 class Dictionary(utils.SaveLoad, Mapping):
     """Dictionary encapsulates the mapping between normalized words and their integer ids.
 
+    Notable instance attributes:
+
     Attributes
-    ---------
+    ----------
     token2id : dict of (str, int)
         token -> tokenId.
     id2token : dict of (int, str)
-        Reverse mapping for token2id, initialized in lazy manner to save memory.
+        Reverse mapping for token2id, initialized in a lazy manner to save memory (not created until needed).
     dfs : dict of (int, int)
-        Document frequencies: token_id -> in how many documents contain this token.
+        Document frequencies: token_id -> how many documents contain this token.
     num_docs : int
         Number of documents processed.
     num_pos : int
         Total number of corpus positions (number of processed words).
     num_nnz : int
-        Total number of non-zeroes in the BOW matrix.
+        Total number of non-zeroes in the BOW matrix (sum of the number of unique
+        words per document over the entire corpus).
 
     """
     def __init__(self, documents=None, prune_at=2000000):
@@ -52,17 +54,17 @@ class Dictionary(utils.SaveLoad, Mapping):
         Parameters
         ----------
         documents : iterable of iterable of str, optional
-            Documents that used for initialization.
+            Documents to be used to initialize the mapping and collect corpus statistics.
         prune_at : int, optional
-            Total number of unique words. Dictionary will keep not more than `prune_at` words.
+            Dictionary will keep no more than `prune_at` words in its mapping, to limit its RAM footprint.
 
         Examples
         --------
         >>> from gensim.corpora import Dictionary
         >>>
         >>> texts = [['human', 'interface', 'computer']]
-        >>> dct = Dictionary(texts)  # fit dictionary
-        >>> dct.add_documents([["cat", "say", "meow"], ["dog"]])  # update dictionary with new documents
+        >>> dct = Dictionary(texts)  # initialize a Dictionary
+        >>> dct.add_documents([["cat", "say", "meow"], ["dog"]])  # add more document (extend the vocabulary)
         >>> dct.doc2bow(["dog", "computer", "non_existent_word"])
         [(0, 1), (6, 1)]
 
@@ -79,12 +81,12 @@ class Dictionary(utils.SaveLoad, Mapping):
             self.add_documents(documents, prune_at=prune_at)
 
     def __getitem__(self, tokenid):
-        """Get token by provided `tokenid`.
+        """Get the string token that corresponds to `tokenid`.
 
         Parameters
         ----------
         tokenid : int
-            Id of token
+            Id of token.
 
         Returns
         -------
@@ -94,7 +96,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         Raises
         ------
         KeyError
-            If `tokenid` isn't contained in :class:`~gensim.corpora.dictionary.Dictionary`.
+            If this Dictionary doesn't contain such `tokenid`.
 
         """
         if len(self.id2token) != len(self.token2id):
@@ -104,7 +106,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         return self.id2token[tokenid]  # will throw for non-existent ids
 
     def __iter__(self):
-        """Iterate over tokens that stored."""
+        """Iterate over all tokens."""
         return iter(self.keys())
 
     if PY3:
@@ -145,7 +147,9 @@ class Dictionary(utils.SaveLoad, Mapping):
 
     @staticmethod
     def from_documents(documents):
-        """Create :class:`~gensim.corpora.dictionary.Dictionary` based on `documents`
+        """Create :class:`~gensim.corpora.dictionary.Dictionary` from `documents`.
+
+        Equivalent to `Dictionary(documents=documents)`.
 
         Parameters
         ----------
@@ -155,7 +159,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         Returns
         -------
         :class:`~gensim.corpora.dictionary.Dictionary`
-            Dictionary filled by `documents`.
+            Dictionary initialized from `documents`.
 
         """
         return Dictionary(documents=documents)
@@ -168,18 +172,17 @@ class Dictionary(utils.SaveLoad, Mapping):
         documents : iterable of iterable of str
             Input corpus. All tokens should be already **tokenized and normalized**.
         prune_at : int, optional
-            Total number of unique words. Dictionary will keep not more than `prune_at` words.
+            Dictionary will keep no more than `prune_at` words in its mapping, to limit its RAM footprint.
 
         Examples
         --------
         >>> from gensim.corpora import Dictionary
         >>>
         >>> corpus = ["máma mele maso".split(), "ema má máma".split()]
-
         >>> dct = Dictionary(corpus)
         >>> len(dct)
         5
-        >>> dct.add_documents([["this","is","sparta"],["just","joking"]])
+        >>> dct.add_documents([["this", "is", "sparta"], ["just", "joking"]])
         >>> len(dct)
         10
 
@@ -200,21 +203,21 @@ class Dictionary(utils.SaveLoad, Mapping):
         )
 
     def doc2bow(self, document, allow_update=False, return_missing=False):
-        """Convert `document` into the bag-of-words (BoW) format = list of (token_id, token_count).
+        """Convert `document` into the bag-of-words (BoW) format = list of `(token_id, token_count)` tuples.
 
         Parameters
         ----------
-        document :  list of str
+        document : list of str
             Input document.
         allow_update : bool, optional
-            If True - update dictionary in the process (i.e. add new tokens and update frequencies).
+            Update self, by adding new tokens from `document` and updating internal corpus statistics.
         return_missing : bool, optional
-            Also return missing tokens (that doesn't contains in current dictionary).
+            Return missing tokens (tokens present in `document` but not in self) with frequencies?
 
         Return
         ------
         list of (int, int)
-            BoW representation of `document`
+            BoW representation of `document`.
         list of (int, int), dict of (str, int)
             If `return_missing` is True, return BoW representation of `document` + dictionary with missing
             tokens and their frequencies.
@@ -223,9 +226,9 @@ class Dictionary(utils.SaveLoad, Mapping):
         --------
         >>> from gensim.corpora import Dictionary
         >>> dct = Dictionary(["máma mele maso".split(), "ema má máma".split()])
-        >>> dct.doc2bow(["this","is","máma"])
+        >>> dct.doc2bow(["this", "is", "máma"])
         [(2, 1)]
-        >>> dct.doc2bow(["this","is","máma"], return_missing=True)
+        >>> dct.doc2bow(["this", "is", "máma"], return_missing=True)
         ([(2, 1)], {u'this': 1, u'is': 1})
 
         """
@@ -245,7 +248,6 @@ class Dictionary(utils.SaveLoad, Mapping):
                     # new id = number of ids made so far;
                     # NOTE this assumes there are no gaps in the id sequence!
                     token2id[w] = len(token2id)
-
         result = {token2id[w]: freq for w, freq in iteritems(counter) if w in token2id}
 
         if allow_update:
@@ -266,9 +268,6 @@ class Dictionary(utils.SaveLoad, Mapping):
 
     def doc2idx(self, document, unknown_word_index=-1):
         """Convert `document` (a list of words) into a list of indexes = list of `token_id`.
-
-        Notes
-        -----
         Replace all unknown words i.e, words not in the dictionary with the index as set via `unknown_word_index`.
 
         Parameters
@@ -281,7 +280,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         Returns
         -------
         list of int
-            Indexes in the dictionary for words in the `document` (preserving the order of words).
+            Token ids for tokens in `document`, in the same order.
 
         Examples
         --------
@@ -300,7 +299,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         return [self.token2id.get(word, unknown_word_index) for word in document]
 
     def filter_extremes(self, no_below=5, no_above=0.5, keep_n=100000, keep_tokens=None):
-        """Filter tokens in dictionary by frequency.
+        """Filter out tokens in the dictionary by their frequency.
 
         Parameters
         ----------
@@ -316,15 +315,15 @@ class Dictionary(utils.SaveLoad, Mapping):
 
         Notes
         -----
-        For tokens that appear in:
+        This removes all tokens in the dictionary that are:
 
-        #. Less than `no_below` documents (absolute number) or \n
-        #. More than `no_above` documents (fraction of total corpus size, **not absolute number**).
-        #. After (1) and (2), keep only the first `keep_n` most frequent tokens (or keep all if `None`).
+        #. Less frequent than `no_below` documents (absolute number, e.g. `5`) or \n
+        #. More frequent than `no_above` documents (fraction of the total corpus size, e.g. `0.3`).
+        #. After (1) and (2), keep only the first `keep_n` most frequent tokens (or keep all if `keep_n=None`).
 
-
-        After the pruning, shrink resulting gaps in word ids.
-        Due to the gap shrinking, the same word may have a different word id before and after the call to this function!
+        After the pruning, resulting gaps in word ids are shrunk.
+        Due to this gap shrinking, **the same word may have a different word id before and after the call
+        to this function!**
 
         Examples
         --------
@@ -401,7 +400,8 @@ class Dictionary(utils.SaveLoad, Mapping):
 
     def filter_tokens(self, bad_ids=None, good_ids=None):
         """Remove the selected `bad_ids` tokens from :class:`~gensim.corpora.dictionary.Dictionary`.
-        Alternative - keep selected `good_ids` in :class:`~gensim.corpora.dictionary.Dictionary` and remove the rest.
+
+        Alternatively, keep selected `good_ids` in :class:`~gensim.corpora.dictionary.Dictionary` and remove the rest.
 
         Parameters
         ----------
@@ -439,7 +439,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         self.compactify()
 
     def compactify(self):
-        """Assign new word ids to all words, shrinking gaps."""
+        """Assign new word ids to all words, shrinking any gaps."""
         logger.debug("rebuilding dictionary, shrinking gaps")
 
         # build mapping from old id -> new id
@@ -458,7 +458,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         fname : str
             Path to output file.
         sort_by_word : bool, optional
-            if True - sort by word in lexicographical order.
+            Sort words in lexicographical order before writing them out?
 
         Notes
         -----
@@ -470,14 +470,15 @@ class Dictionary(utils.SaveLoad, Mapping):
             ....
             id_k[TAB]word_k[TAB]document_frequency_k[NEWLINE]
 
-        Warnings
-        --------
-        Text format should be use for corpus inspection. Use :meth:`~gensim.corpora.dictionary.Dictionary.save` and
-        :meth:`~gensim.corpora.dictionary.Dictionary.load` to store in binary format (pickle) for better performance.
+        This text format is great for corpus inspection and debugging. As plaintext, it's also easily portable
+        to other tools and frameworks. For better performance and to store the entire object state,
+        including collected corpus statistics, use :meth:`~gensim.corpora.dictionary.Dictionary.save` and
+        :meth:`~gensim.corpora.dictionary.Dictionary.load` instead.
 
         See Also
         --------
         :meth:`~gensim.corpora.dictionary.Dictionary.load_from_text`
+            Load :class:`~gensim.corpora.dictionary.Dictionary` from text file.
 
         Examples
         --------
@@ -490,7 +491,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         >>> dct = Dictionary(corpus)
         >>> dct.save_as_text(tmp_fname)
         >>>
-        >>> loaded_dct = Dictionary.load_from_text("testdata")
+        >>> loaded_dct = Dictionary.load_from_text(tmp_fname)
         >>> assert dct.token2id == loaded_dct.token2id
 
         """
@@ -508,23 +509,20 @@ class Dictionary(utils.SaveLoad, Mapping):
                     fout.write(utils.to_utf8(line))
 
     def merge_with(self, other):
-        """Merge another dictionary into this dictionary, mapping same tokens to the same ids and new tokens to new ids.
+        """Merge another dictionary into this dictionary, mapping the same tokens to the same ids
+        and new tokens to new ids.
 
         Notes
         -----
         The purpose is to merge two corpora created using two different dictionaries: `self` and `other`.
         `other` can be any id=>word mapping (a dict, a Dictionary object, ...).
 
-        Get a transformation object which, when accessed as `result[doc_from_other_corpus]`, will convert documents
+        Return a transformation object which, when accessed as `result[doc_from_other_corpus]`, will convert documents
         from a corpus built using the `other` dictionary into a document using the new, merged dictionary.
 
-        Warnings
-        --------
-        This method will change `self` dictionary.
-
         Parameters
         ----------
-        other : :class:`~gensim.corpora.dictionary.Dictionary`
+        other : {dict, :class:`~gensim.corpora.dictionary.Dictionary`}
             Other dictionary.
 
         Return
@@ -572,16 +570,18 @@ class Dictionary(utils.SaveLoad, Mapping):
     @staticmethod
     def load_from_text(fname):
         """Load a previously stored :class:`~gensim.corpora.dictionary.Dictionary` from a text file.
+
         Mirror function to :meth:`~gensim.corpora.dictionary.Dictionary.save_as_text`.
 
         Parameters
         ----------
         fname: str
-            Path to file produced by :meth:`~gensim.corpora.dictionary.Dictionary.save_as_text`.
+            Path to a file produced by :meth:`~gensim.corpora.dictionary.Dictionary.save_as_text`.
 
         See Also
         --------
         :meth:`~gensim.corpora.dictionary.Dictionary.save_as_text`
+            Save :class:`~gensim.corpora.dictionary.Dictionary` to text file.
 
         Examples
         --------
@@ -594,7 +594,7 @@ class Dictionary(utils.SaveLoad, Mapping):
         >>> dct = Dictionary(corpus)
         >>> dct.save_as_text(tmp_fname)
         >>>
-        >>> loaded_dct = Dictionary.load_from_text("testdata")
+        >>> loaded_dct = Dictionary.load_from_text(tmp_fname)
         >>> assert dct.token2id == loaded_dct.token2id
 
         """
