@@ -4,14 +4,14 @@
 # Copyright (C) 2012 Homer Strong, Radim Rehurek
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
 
-
-"""This module implements the "hashing trick" [1]_ -- a mapping between words and their integer ids
-using a fixed and static mapping.
+"""Implements the `"hashing trick" <http://en.wikipedia.org/wiki/Hashing-Trick>`_ -- a mapping between words
+and their integer ids using a fixed, static mapping (hash function).
 
 Notes
 -----
+
 The static mapping has a constant memory footprint, regardless of the number of word-types (features) in your corpus,
-so it's suitable for processing extremely large corpora. The ids are computed as `hash(word) % id_range`,
+so it's suitable for processing extremely large corpora. The ids are computed as `hash(word) %% id_range`,
 where `hash` is a user-configurable function (`zlib.adler32` by default).
 
 Advantages:
@@ -19,18 +19,11 @@ Advantages:
 * New words can be represented immediately, without an extra pass through the corpus
   to collect all the ids first.
 * Can be used with non-repeatable (once-only) streams of documents.
-* All tokens will be used (not only that you see in documents), typical problem
-  for :class:`~gensim.corpora.dictionary.Dictionary`.
-
+* Able to represent any token (not only those present in training documents)
 
 Disadvantages:
 
-* Words may map to the same id, causing hash collisions. The word <-> id mapping is no longer a bijection.
-
-
-References
-----------
-.. [1] http://en.wikipedia.org/wiki/Hashing-Trick
+* Multiple words may map to the same id, causing hash collisions. The word <-> id mapping is no longer a bijection.
 
 """
 
@@ -48,21 +41,20 @@ logger = logging.getLogger(__name__)
 
 
 class HashDictionary(utils.SaveLoad, dict):
-    """Encapsulates the mapping between normalized words and their integer ids.
+    """Mapping between words and their integer ids, using a hashing function.
 
-    Notes
-    -----
     Unlike :class:`~gensim.corpora.dictionary.Dictionary`,
     building a :class:`~gensim.corpora.hashdictionary.HashDictionary` before using it **isn't a necessary step**.
-    The documents can be computed immediately, from an uninitialized
-    :class:`~gensim.corpora.hashdictionary.HashDictionary` without seeing the rest of the corpus first.
+
+    You can start converting words to ids immediately, without training on a corpus.
 
     Examples
     --------
     >>> from gensim.corpora import HashDictionary
     >>>
+    >>> dct = HashDictionary(debug=False)  # needs no training corpus!
+    >>>
     >>> texts = [['human', 'interface', 'computer']]
-    >>> dct = HashDictionary(texts)
     >>> dct.doc2bow(texts[0])
     [(10608, 1), (12466, 1), (31002, 1)]
 
@@ -72,15 +64,18 @@ class HashDictionary(utils.SaveLoad, dict):
 
         Parameters
         ----------
-        documents : iterable of iterable of str
-            Iterable of documents, if given - use them to initialization.
+        documents : iterable of iterable of str, optional
+            Iterable of documents. If given, used to collect additional corpus statistics.
+            :class:`~gensim.corpora.hashdictionary.HashDictionary` can work
+            without these statistics (optional parameter).
         id_range : int, optional
-            Number of hash-values in table, used as `id = myhash(key) % id_range`.
-        myhash : function
-            Hash function, should support interface myhash(str) -> int, used `zlib.adler32` by default.
-        debug : bool
-            If True - store raw tokens mapping (as str <-> id).
-            If you find yourself running out of memory (or not sure that you really need raw tokens), set `debug=False`.
+            Number of hash-values in table, used as `id = myhash(key) %% id_range`.
+        myhash : function, optional
+            Hash function, should support interface `myhash(str) -> int`, uses `zlib.adler32` by default.
+        debug : bool, optional
+            Store which tokens have mapped to a given id? **Will use a lot of RAM**.
+            If you find yourself running out of memory (or not sure that you really need raw tokens),
+            keep `debug=False`.
 
         """
         self.myhash = myhash  # hash fnc: string->integer
@@ -106,7 +101,8 @@ class HashDictionary(utils.SaveLoad, dict):
 
         Warnings
         --------
-        Works only if `debug=True`.
+        Works only if you initialized your :class:`~gensim.corpora.hashdictionary.HashDictionary` object
+        with `debug=True`.
 
         Parameters
         ----------
@@ -116,14 +112,14 @@ class HashDictionary(utils.SaveLoad, dict):
         Return
         ------
         set of str
-            Set of all corresponding words.
+            Set of all words that have mapped to this id.
 
         """
         return self.id2token.get(tokenid, set())
 
     def restricted_hash(self, token):
         """Calculate id of the given token.
-        Also keep track of what words were mapped to what ids, for debugging reasons.
+        Also keep track of what words were mapped to what ids, if `debug=True` was set in the constructor.
 
         Parameters
         ----------
@@ -158,7 +154,11 @@ class HashDictionary(utils.SaveLoad, dict):
         return HashDictionary(*args, **kwargs)
 
     def add_documents(self, documents):
-        """Build dictionary from a collection of documents.
+        """Collect corpus statistics from a corpus.
+
+        Warnings
+        --------
+        Useful only if `debug=True`, to build the reverse `id=>set(words)` mapping.
 
         Notes
         -----
@@ -171,13 +171,15 @@ class HashDictionary(utils.SaveLoad, dict):
 
         Examples
         --------
+
         >>> from gensim.corpora import HashDictionary
         >>>
+        >>> dct = HashDictionary(debug=True)  # needs no training corpus!
+        >>>
         >>> corpus = [["máma", "mele", "maso"], ["ema", "má", "máma"]]
-        >>> dct = HashDictionary(corpus)
         >>> "sparta" in dct.token2id
         False
-        >>> dct.add_documents([["this","is","sparta"],["just","joking"]])  # add more documents in dictionary
+        >>> dct.add_documents([["this", "is", "sparta"], ["just", "joking"]])
         >>> "sparta" in dct.token2id
         True
 
@@ -192,43 +194,39 @@ class HashDictionary(utils.SaveLoad, dict):
         )
 
     def doc2bow(self, document, allow_update=False, return_missing=False):
-        """Convert `document` into the bag-of-words format, like [(1, 4), (150, 1), (2005, 2)].
+        """Convert a sequence of words `document` into the bag-of-words format of `[(word_id, word_count)]`
+        (e.g. `[(1, 4), (150, 1), (2005, 2)]`).
 
         Notes
         -----
-        Each word is assumed to be a **tokenized and normalized** utf-8 encoded string. No further preprocessing
-        is done on the words in `document` (apply tokenization, stemming etc) before calling this method.
+        Each word is assumed to be a **tokenized and normalized** string. No further preprocessing
+        is done on the words in `document`: you have to apply tokenization, stemming etc before calling this method.
 
-        If `allow_update` or `self.allow_update` is set, then also update dictionary in the process: update overall
+        If `allow_update` or `self.allow_update` is set, then also update the dictionary in the process: update overall
         corpus statistics and document frequencies. For each id appearing in this document, increase its document
         frequency (`self.dfs`) by one.
 
         Parameters
         ----------
-        document : list of str
-            Is a list of tokens = **tokenized and normalized** strings (either utf8 or unicode).
+        document : sequence of str
+            A sequence of word tokens = **tokenized and normalized** strings.
         allow_update : bool, optional
-            If True - update dictionary in the process.
+            Update corpus statistics and if `debug=True`, also the reverse id=>word mapping?
         return_missing : bool, optional
-            Show token_count for missing words. HAVE NO SENSE FOR THIS CLASS, BECAUSE WE USING HASHING-TRICK.
+            Not used. Only here for compatibility with the Dictionary class.
 
         Return
         ------
         list of (int, int)
             Document in Bag-of-words (BoW) format.
-        list of (int, int), dict
-            If `return_missing=True`, return document in Bag-of-words (BoW) format + empty dictionary.
 
         Examples
         --------
         >>> from gensim.corpora import HashDictionary
         >>>
-        >>> corpus = [["máma", "mele", "maso"], ["ema", "má", "máma"]]
-        >>> dct = HashDictionary(corpus)
-        >>> dct.doc2bow(["this","is","máma"])
+        >>> dct = HashDictionary()
+        >>> dct.doc2bow(["this", "is", "máma"])
         [(1721, 1), (5280, 1), (22493, 1)]
-        >>> dct.doc2bow(["this","is","máma"], return_missing=True)
-        ([(1721, 1), (5280, 1), (22493, 1)], {})
 
         """
         result = {}
@@ -260,7 +258,15 @@ class HashDictionary(utils.SaveLoad, dict):
             return result
 
     def filter_extremes(self, no_below=5, no_above=0.5, keep_n=100000):
-        """Filter tokens in dictionary by frequency.
+        """Filter tokens in the debug dictionary by their frequency.
+
+        Since :class:`~gensim.corpora.hashdictionary.HashDictionary` id range is fixed and doesn't depend on the number
+        of tokens seen, this doesn't really "remove" anything. It only clears some
+        internal corpus statistics, for easier debugging and a smaller RAM footprint.
+
+        Warnings
+        --------
+        Only makes sense when `debug=True`.
 
         Parameters
         ----------
@@ -280,20 +286,6 @@ class HashDictionary(utils.SaveLoad, dict):
         #. More than `no_above` documents (fraction of total corpus size, **not absolute number**).
         #. After (1) and (2), keep only the first `keep_n` most frequent tokens (or keep all if `None`).
 
-        Since :class:`~gensim.corpora.hashdictionary.HashDictionary` id range is fixed and doesn't depend on the number
-        of tokens seen, this doesn't really "remove" anything.
-        It only clears some supplementary statistics, for easier debugging and a smaller RAM footprint.
-
-        Examples
-        --------
-        >>> from gensim.corpora import HashDictionary
-        >>>
-        >>> corpus = [["máma", "mele", "maso"], ["ema", "má", "máma"]]
-        >>> dct = HashDictionary(corpus)
-        >>> dct.filter_extremes(no_below=1, no_above=0.5, keep_n=1)
-        >>> print dct.token2id
-        {'maso': 15025}
-
         """
         no_above_abs = int(no_above * self.num_docs)  # convert fractional threshold to absolute threshold
         ok = [item for item in iteritems(self.dfs_debug) if no_below <= item[1] <= no_above_abs]
@@ -314,7 +306,11 @@ class HashDictionary(utils.SaveLoad, dict):
         )
 
     def save_as_text(self, fname):
-        """Save this HashDictionary to a text file.
+        """Save the debug token=>id mapping to a text file.
+
+        Warnings
+        --------
+        Only makes sense when `debug=True`, for debugging.
 
         Parameters
         ----------
@@ -337,7 +333,7 @@ class HashDictionary(utils.SaveLoad, dict):
         >>> data.save_as_text(get_tmpfile("dictionary_in_text_format"))
 
         """
-        logger.info("saving HashDictionary mapping to %s" % fname)
+        logger.info("saving %s mapping to %s" % (self, fname))
         with utils.smart_open(fname, 'wb') as fout:
             for tokenid in self.keys():
                 words = sorted(self[tokenid])
