@@ -6,19 +6,16 @@
 # Copyright (C) 2018 Emmanouil Stergiadis <em.stergiadis@gmail.com>
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
 
-
 """Construct a corpus from a Wikipedia (or other MediaWiki-based) database dump.
 
+Uses multiprocessing internally to parallelize the work and process the dump more quickly.
+
 Notes
 -----
-If you have the `pattern` package installed, this module will use a fancy lemmatization to get a lemma
-of each token (instead of plain alphabetic tokenizer). The package is available at [1]_ .
+If you have the `pattern <https://github.com/clips/pattern>`_ package installed,
+this module will use a fancy lemmatization to get a lemma of each token (instead of plain alphabetic tokenizer).
 
-See :mod:`~gensim.scripts.make_wiki` for a canned (example) script based on this module.
-
-References
-----------
-.. [1] https://github.com/clips/pattern
+See :mod:`gensim.scripts.make_wiki` for a canned (example) command-line script based on this module.
 
 """
 
@@ -68,9 +65,9 @@ RE_P10 = re.compile(r'<math([> ].*?)(</math>|/>)', re.DOTALL | re.UNICODE)
 """Math content."""
 RE_P11 = re.compile(r'<(.*?)>', re.DOTALL | re.UNICODE)
 """All other tags."""
-RE_P12 = re.compile(r'\n(({\|)|(\|-)|(\|}))(.*?)(?=\n)', re.UNICODE)
+RE_P12 = re.compile(r'(({\|)|(\|-(?!\d))|(\|}))(.*?)(?=\n)', re.UNICODE)
 """Table formatting."""
-RE_P13 = re.compile(r'\n(\||\!)(.*?\|)*([^|]*?)', re.UNICODE)
+RE_P13 = re.compile(r'(?<=(\n[ ])|(\n\n)|([ ]{2})|(.\n)|(.\t))(\||\!)([^[\]\n]*?\|)*', re.UNICODE)
 """Table cell formatting."""
 RE_P14 = re.compile(r'\[\[Category:[^][]*\]\]', re.UNICODE)
 """Categories."""
@@ -78,19 +75,18 @@ RE_P15 = re.compile(r'\[\[([fF]ile:|[iI]mage)[^]]*(\]\])', re.UNICODE)
 """Remove File and Image templates."""
 RE_P16 = re.compile(r'\[{2}(.*?)\]{2}', re.UNICODE)
 """Capture interlinks text and article linked"""
-
+RE_P17 = re.compile(
+    r'(\n.{0,4}((bgcolor)|(\d{0,1}[ ]?colspan)|(rowspan)|(style=)|(class=)|(align=)|(scope=))(.*))|'
+    '(^.{0,2}((bgcolor)|(\d{0,1}[ ]?colspan)|(rowspan)|(style=)|(class=)|(align=))(.*))',
+    re.UNICODE
+)
+"""Table markup"""
 IGNORED_NAMESPACES = [
     'Wikipedia', 'Category', 'File', 'Portal', 'Template',
     'MediaWiki', 'User', 'Help', 'Book', 'Draft', 'WikiProject',
     'Special', 'Talk'
 ]
-"""MediaWiki namespaces [2]_ that ought to be ignored.
-
-References
-----------
-.. [2] https://www.mediawiki.org/wiki/Manual:Namespace
-
-"""
+"""`MediaWiki namespaces <https://www.mediawiki.org/wiki/Manual:Namespace>`_ that ought to be ignored."""
 
 
 def find_interlinks(raw):
@@ -105,6 +101,7 @@ def find_interlinks(raw):
     -------
     dict
         Mapping from the linked article to the actual text found.
+
     """
     filtered = filter_wiki(raw, promote_remaining=False, simplify_links=False)
     interlinks_raw = re.findall(RE_P16, filtered)
@@ -138,6 +135,7 @@ def filter_wiki(raw, promote_remaining=True, simplify_links=True):
     -------
     str
         `raw` without markup.
+
     """
     # parsing of the wiki markup is not perfect, but sufficient for our purposes
     # contributions to improving this code are welcome :)
@@ -185,10 +183,14 @@ def remove_markup(text, promote_remaining=True, simplify_links=True):
         if simplify_links:
             text = re.sub(RE_P6, '\\2', text)  # simplify links, keep description only
         # remove table markup
-
-        text = text.replace('||', '\n|')  # each table cell on a separate line
+        text = text.replace("!!", "\n|")  # each table head cell on a separate line
+        text = text.replace("|-||", "\n|")  # for cases where a cell is filled with '-'
         text = re.sub(RE_P12, '\n', text)  # remove formatting lines
-        text = re.sub(RE_P13, '\n\\3', text)  # leave only cell content
+        text = text.replace('|||', '|\n|')  # each table cell on a separate line(where |{{a|b}}||cell-content)
+        text = text.replace('||', '\n|')  # each table cell on a separate line
+        text = re.sub(RE_P13, '\n', text)  # leave only cell content
+        text = re.sub(RE_P17, '\n', text)  # remove formatting lines
+
         # remove empty mark-up
         text = text.replace('[]', '')
         # stop if nothing changed between two iterations or after a fixed number of iterations
@@ -212,18 +214,13 @@ def remove_template(s):
     Returns
     -------
     str
-        Сopy of `s` with all the wikimedia markup template removed. See [4]_ for wikimedia templates details.
+        Сopy of `s` with all the `wikimedia markup template <http://meta.wikimedia.org/wiki/Help:Template>`_ removed.
 
     Notes
     -----
     Since template can be nested, it is difficult remove them using regular expressions.
 
-    References
-    ----------
-    .. [4] http://meta.wikimedia.org/wiki/Help:Template
-
     """
-
     # Find the start and end position of each template by finding the opening
     # '{{' and closing '}}'
     n_open, n_close = 0, 0
@@ -262,11 +259,8 @@ def remove_file(s):
     Returns
     -------
     str
-        Сopy of `s` with all the 'File:' and 'Image:' markup replaced by their corresponding captions. [3]_
-
-    References
-    ----------
-    .. [3] http://www.mediawiki.org/wiki/Help:Images
+        Сopy of `s` with all the 'File:' and 'Image:' markup replaced by their `corresponding captions
+        <http://www.mediawiki.org/wiki/Help:Images>`_.
 
     """
     # The regex RE_P15 match a File: or Image: markup
@@ -278,7 +272,7 @@ def remove_file(s):
 
 
 def tokenize(content, token_min_len=TOKEN_MIN_LEN, token_max_len=TOKEN_MAX_LEN, lower=True):
-    """Tokenize a piece of text from wikipedia.
+    """Tokenize a piece of text from Wikipedia.
 
     Set `token_min_len`, `token_max_len` as character length (not bytes!) thresholds for individual tokens.
 
@@ -291,7 +285,7 @@ def tokenize(content, token_min_len=TOKEN_MIN_LEN, token_max_len=TOKEN_MAX_LEN,
     token_max_len : int
         Maximal token length.
     lower : bool
-         If True - convert `content` to lower case.
+         Convert `content` to lower case?
 
     Returns
     -------
@@ -389,12 +383,12 @@ _extract_pages = extract_pages  # for backward compatibility
 
 def process_article(args, tokenizer_func=tokenize, token_min_len=TOKEN_MIN_LEN,
                     token_max_len=TOKEN_MAX_LEN, lower=True):
-    """Parse a wikipedia article, extract all tokens.
+    """Parse a Wikipedia article, extract all tokens.
 
     Notes
     -----
     Set `tokenizer_func` (defaults is :func:`~gensim.corpora.wikicorpus.tokenize`) parameter for languages
-    like japanese or thai to perform better tokenization.
+    like Japanese or Thai to perform better tokenization.
     The `tokenizer_func` needs to take 4 parameters: (text: str, token_min_len: int, token_max_len: int, lower: bool).
 
     Parameters
@@ -411,7 +405,7 @@ def process_article(args, tokenizer_func=tokenize, token_min_len=TOKEN_MIN_LEN,
     token_max_len : int
         Maximal token length.
     lower : bool
-         If True - convert article text to lower case.
+         Convert article text to lower case?
 
     Returns
     -------
@@ -469,7 +463,7 @@ def _process_article(args):
 
 
 class WikiCorpus(TextCorpus):
-    """Treat a wikipedia articles dump as a **read-only** corpus.
+    """Treat a Wikipedia articles dump as a read-only, streamed, memory-efficient corpus.
 
     Supported dump formats:
 
@@ -480,7 +474,7 @@ class WikiCorpus(TextCorpus):
 
     Notes
     -----
-    Dumps for English wikipedia can be founded `here <https://dumps.wikimedia.org/enwiki/>`_.
+    Dumps for the English Wikipedia can be founded at https://dumps.wikimedia.org/enwiki/.
 
     Attributes
     ----------
@@ -494,39 +488,39 @@ class WikiCorpus(TextCorpus):
 
     Examples
     --------
+    >>> from gensim.test.utils import datapath, get_tmpfile
     >>> from gensim.corpora import WikiCorpus, MmCorpus
     >>>
-    >>> wiki = WikiCorpus('enwiki-20100622-pages-articles.xml.bz2') # create word->word_id mapping, takes almost 8h
-    >>> MmCorpus.serialize('wiki_en_vocab200k.mm', wiki) # another 8h, creates a file in MatrixMarket format and mapping
+    >>> path_to_wiki_dump = datapath("enwiki-latest-pages-articles1.xml-p000000010p000030302-shortened.bz2")
+    >>> corpus_path = get_tmpfile("wiki-corpus.mm")
+    >>>
+    >>> wiki = WikiCorpus(path_to_wiki_dump) # create word->word_id mapping, ~8h on full wiki
+    >>> MmCorpus.serialize(corpus_path, wiki) # another 8h, creates a file in MatrixMarket format and mapping
 
     """
-
     def __init__(self, fname, processes=None, lemmatize=utils.has_pattern(), dictionary=None,
                  filter_namespaces=('0',), tokenizer_func=tokenize, article_min_tokens=ARTICLE_MIN_WORDS,
                  token_min_len=TOKEN_MIN_LEN, token_max_len=TOKEN_MAX_LEN, lower=True):
-        """Initialize the corpus.
-
-        Unless a dictionary is provided, this scans the corpus once,
-        to determine its vocabulary.
+        """
 
         Parameters
         ----------
         fname : str
-            Path to file with wikipedia dump.
+            Path to the Wikipedia dump file.
         processes : int, optional
-            Number of processes to run, defaults to **number of cpu - 1**.
+            Number of processes to run, defaults to `max(1, number of cpu - 1)`.
         lemmatize : bool
-            Whether to use lemmatization instead of simple regexp tokenization.
-            Defaults to `True` if *pattern* package installed.
+            Use lemmatization instead of simple regexp tokenization.
+            Defaults to `True` if you have the `pattern <https://github.com/clips/pattern>`_ package installed.
         dictionary : :class:`~gensim.corpora.dictionary.Dictionary`, optional
             Dictionary, if not provided,  this scans the corpus once, to determine its vocabulary
-            (this needs **really long time**).
-        filter_namespaces : tuple of str
+            **IMPORTANT: this needs a really long time**.
+        filter_namespaces : tuple of str, optional
             Namespaces to consider.
         tokenizer_func : function, optional
             Function that will be used for tokenization. By default, use :func:`~gensim.corpora.wikicorpus.tokenize`.
-            Need to support interface:
-            tokenizer_func(text: str, token_min_len: int, token_max_len: int, lower: bool) -> list of str.
+            If you inject your own tokenizer, it must conform to this interface:
+            `tokenizer_func(text: str, token_min_len: int, token_max_len: int, lower: bool) -> list of str`
         article_min_tokens : int, optional
             Minimum tokens in article. Article will be ignored if number of tokens is less.
         token_min_len : int, optional
@@ -534,7 +528,11 @@ class WikiCorpus(TextCorpus):
         token_max_len : int, optional
             Maximal token length.
         lower : bool, optional
-             If True - convert all text to lower case.
+             Convert all text to lower case?
+
+        Warnings
+        --------
+        Unless a dictionary is provided, this scans the corpus once, to determine its vocabulary.
 
         """
         self.fname = fname
@@ -549,18 +547,32 @@ class WikiCorpus(TextCorpus):
         self.token_min_len = token_min_len
         self.token_max_len = token_max_len
         self.lower = lower
-        self.dictionary = dictionary or Dictionary(self.get_texts())
+
+        if dictionary is None:
+            self.dictionary = Dictionary(self.get_texts())
+        else:
+            self.dictionary = dictionary
 
     def get_texts(self):
-        """Iterate over the dump, yielding list of tokens for each article.
+        """Iterate over the dump, yielding a list of tokens for each article that passed
+        the length and namespace filtering.
+
+        Uses multiprocessing internally to parallelize the work and process the dump more quickly.
 
         Notes
         -----
         This iterates over the **texts**. If you want vectors, just use the standard corpus interface
         instead of this method:
 
-        >>> for vec in wiki_corpus:
-        >>>     print(vec)
+        Examples
+        --------
+        >>> from gensim.test.utils import datapath
+        >>> from gensim.corpora import WikiCorpus
+        >>>
+        >>> path_to_wiki_dump = datapath("enwiki-latest-pages-articles1.xml-p000000010p000030302-shortened.bz2")
+        >>>
+        >>> for vec in WikiCorpus(path_to_wiki_dump):
+        ...     pass
 
         Yields
         ------
@@ -570,7 +582,6 @@ class WikiCorpus(TextCorpus):
             List of tokens (extracted from the article), page id and article title otherwise.
 
         """
-
         articles, articles_all = 0, 0
         positions, positions_all = 0, 0
 
