@@ -113,7 +113,7 @@ def asfarray(a, name=''):
     a : numpy.ndarray
         Input array.
     name : str, optional
-        Array name, used for logging purposes.
+        Array name, used only for logging purposes.
 
     Returns
     -------
@@ -150,7 +150,7 @@ def ascarray(a, name=''):
 
 
 class Projection(utils.SaveLoad):
-    """Lower dimension projections of a Term-Passage matrix.
+    """Low dimensional projection of a term-document matrix.
 
     This is the class taking care of the 'core math': interfacing with corpora, splitting large corpora into chunks
     and merging them etc. This done through the higher-level :class:`~gensim.models.lsimodel.LsiModel` class.
@@ -158,7 +158,7 @@ class Projection(utils.SaveLoad):
     Notes
     -----
     The projection can be later updated by merging it with another :class:`~gensim.models.lsimodel.Projection`
-    via  :meth:`~gensim.models.lsimodel.Projection.merge`.
+    via  :meth:`~gensim.models.lsimodel.Projection.merge`. This is how incremental training actually happens.
 
     """
     def __init__(self, m, k, docs=None, use_svdlibc=False, power_iters=P2_EXTRA_ITERS,
@@ -321,7 +321,7 @@ class LsiModel(interfaces.TransformationABC, basemodel.BaseTopicModel):
     """Model for `Latent Semantic Indexing
     <https://en.wikipedia.org/wiki/Latent_semantic_analysis#Latent_semantic_indexing>`_.
 
-    Algorithm of decomposition described in `"Fast and Faster: A Comparison of Two Streamed
+    The decomposition algorithm is described in `"Fast and Faster: A Comparison of Two Streamed
     Matrix Decomposition Algorithms" <https://nlp.fi.muni.cz/~xrehurek/nips/rehurek_nips.pdf>`_.
 
     Notes
@@ -616,7 +616,7 @@ class LsiModel(interfaces.TransformationABC, basemodel.BaseTopicModel):
         Notes
         -----
         The number of topics can actually be smaller than `self.num_topics`, if there were not enough factors
-        (real rank of input matrix smaller than `self.num_topics`).
+        in the matrix (real rank of input matrix smaller than `self.num_topics`).
 
         Returns
         -------
@@ -636,8 +636,10 @@ class LsiModel(interfaces.TransformationABC, basemodel.BaseTopicModel):
     def show_topic(self, topicno, topn=10):
         """Get the words that define a topic along with their contribution.
 
-        This is actually the left singular vector of the specified topic. The most important words in defining the topic
-        (in both directions) are included in the string, along with their contribution to the topic.
+        This is actually the left singular vector of the specified topic.
+
+        The most important words in defining the topic (greatest absolute value) are included
+        in the output, along with their contribution to the topic.
 
         Parameters
         ----------
@@ -758,7 +760,7 @@ class LsiModel(interfaces.TransformationABC, basemodel.BaseTopicModel):
 
         Notes
         -----
-        Large arrays can be memmap'ed back as read-only (shared memory) by setting `mmap='r'`:
+        Large arrays can be memmap'ed back as read-only (shared memory) by setting the `mmap='r'` parameter.
 
         Parameters
         ----------
