@@ -6,16 +6,33 @@
 # Based on Copyright (C) 2014 Radim Rehurek <radimrehurek@seznam.cz>
 
 
-"""
-Python wrapper for Dynamic Topic Models (DTM) and the Document Influence Model (DIM)  [1].
+"""Python wrapper for `Dynamic Topic Models (DTM) <http://www.cs.columbia.edu/~blei/papers/BleiLafferty2006a.pdf>`_
+and the `Document Influence Model (DIM) <http://www.cs.columbia.edu/~blei/papers/GerrishBlei2010.pdf>`_.
 
-This module allows for DTM and DIM model estimation from a training corpus.
+Installation
+------------
 
-Example:
+You have 2 ways, how to make binaries:
 
->>> model = gensim.models.wrappers.DtmModel('dtm-win64.exe', my_corpus, my_timeslices, num_topics=20, id2word=dictionary)
+#. Use precompiled binaries for your OS version from `/magsilva/dtm/ <https://github.com/magsilva/dtm/tree/master/bin>`_
+#. Compile binaries manually from `/blei-lab/dtm <https://github.com/blei-lab/dtm.git>`_
+   (original instruction available in https://github.com/blei-lab/dtm/blob/master/README.md), or use this ::
 
-.. [1] https://github.com/magsilva/dtm/tree/master/bin
+    git clone https://github.com/blei-lab/dtm.git
+    sudo apt-get install libgsl0-dev
+    cd dtm/dtm
+    make
+
+Examples
+--------
+>>> from gensim.test.utils import common_corpus, common_dictionary
+>>> from gensim.models.wrappers import DtmModel
+>>>
+>>> path_to_dtm_binary = "/path/to/dtm/binary"
+>>> model = DtmModel(
+...    path_to_dtm_binary, corpus=common_corpus, id2word=common_dictionary,
+...    time_slices=[1] * len(common_corpus)
+... )
 
 """
 
@@ -35,40 +52,55 @@ logger = logging.getLogger(__name__)
 
 
 class DtmModel(utils.SaveLoad):
-    """
-    Class for DTM training using DTM binary. Communication between DTM and Python
-    takes place by passing around data files on disk and executing the DTM binary as a subprocess.
+    """Python wrapper using `DTM implementation <https://github.com/magsilva/dtm/tree/master/bin>`_.
+
+    Communication between DTM and Python takes place by passing around data files on disk and executing
+    the DTM binary as a subprocess.
+
+    Warnings
+    --------
+    This is **only** python wrapper for `DTM implementation <https://github.com/magsilva/dtm/tree/master/bin>`_,
+    you need to install original implementation first and pass the path to binary to ``dtm_path``.
 
     """
-
     def __init__(self, dtm_path, corpus=None, time_slices=None, mode='fit', model='dtm', num_topics=100,
                  id2word=None, prefix=None, lda_sequence_min_iter=6, lda_sequence_max_iter=20, lda_max_em_iter=10,
                  alpha=0.01, top_chain_var=0.005, rng_seed=0, initialize_lda=True):
         """
-        `dtm_path` is path to the dtm executable, e.g. `C:/dtm/dtm-win64.exe`.
 
-        `corpus` is a gensim corpus, aka a stream of sparse document vectors.
-
-        `id2word` is a mapping between tokens ids and token.
-
-        `mode` controls the mode of the mode: 'fit' is for training, 'time' for
-        analyzing documents through time according to a DTM, basically a held out set.
-
-        `model` controls the choice of model. 'fixed' is for DIM and 'dtm' for DTM.
-
-        `lda_sequence_min_iter` min iteration of LDA.
-
-        `lda_sequence_max_iter` max iteration of LDA.
-
-        `lda_max_em_iter` max em optiimzatiion iterations in LDA.
-
-        `alpha` is a hyperparameter that affects sparsity of the document-topics for the LDA models in each timeslice.
-
-        `top_chain_var` is a hyperparameter that affects.
-
-        `rng_seed` is the random seed.
-
-        `initialize_lda` initialize DTM with LDA.
+        Parameters
+        ----------
+        dtm_path : str
+            Path to the dtm binary, e.g. `/home/username/dtm/dtm/main`.
+        corpus : iterable of iterable of (int, int)
+            Collection of texts in BoW format.
+        time_slices : list of int
+            Sequence of timestamps.
+        mode : {'fit', 'time'}, optional
+            Controls the mode of the mode: 'fit' is for training, 'time' for analyzing documents through time
+            according to a DTM, basically a held out set.
+        model : {'fixed', 'dtm'}, optional
+            Control model that will be runned: 'fixed' is for DIM and 'dtm' for DTM.
+        num_topics : int, optional
+            Number of topics.
+        id2word : :class:`~gensim.corpora.dictionary.Dictionary`, optional
+            Mapping between tokens ids and words from corpus, if not specified - will be inferred from `corpus`.
+        prefix : str, optional
+            Prefix for produced temporary files.
+        lda_sequence_min_iter : int, optional
+             Min iteration of LDA.
+        lda_sequence_max_iter : int, optional
+            Max iteration of LDA.
+        lda_max_em_iter : int, optional
+             Max em optimization iterations in LDA.
+        alpha : int, optional
+            Hyperparameter that affects sparsity of the document-topics for the LDA models in each timeslice.
+        top_chain_var : int, optional
+            Hyperparameter that affects.
+        rng_seed : int, optional
+             Random seed.
+        initialize_lda : bool, optional
+             If True - initialize DTM with LDA.
 
         """
         if not os.path.isfile(dtm_path):
@@ -130,47 +162,158 @@ class DtmModel(utils.SaveLoad):
             self.train(corpus, time_slices, mode, model)
 
     def fout_liklihoods(self):
+        """Get path to temporary lhood data file.
+
+        Returns
+        -------
+        str
+            Path to lhood data file.
+
+        """
         return self.prefix + 'train_out/lda-seq/' + 'lhoods.dat'
 
     def fout_gamma(self):
+        """Get path to temporary gamma data file.
+
+        Returns
+        -------
+        str
+            Path to gamma data file.
+
+        """
         return self.prefix + 'train_out/lda-seq/' + 'gam.dat'
 
     def fout_prob(self):
+        """Get template of path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to file.
+
+        """
         return self.prefix + 'train_out/lda-seq/' + 'topic-{i}-var-e-log-prob.dat'
 
     def fout_observations(self):
+        """Get template of path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to file.
+
+        """
         return self.prefix + 'train_out/lda-seq/' + 'topic-{i}-var-obs.dat'
 
     def fout_influence(self):
+        """Get template of path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to file.
+
+        """
         return self.prefix + 'train_out/lda-seq/' + 'influence_time-{i}'
 
     def foutname(self):
+        """Get path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to file.
+
+        """
         return self.prefix + 'train_out'
 
     def fem_steps(self):
+        """Get path to temporary em_step data file.
+
+        Returns
+        -------
+        str
+            Path to em_step data file.
+
+        """
         return self.prefix + 'train_out/' + 'em_log.dat'
 
     def finit_alpha(self):
+        """Get path to initially trained lda alpha file.
+
+        Returns
+        -------
+        str
+            Path to initially trained lda alpha file.
+
+        """
         return self.prefix + 'train_out/' + 'initial-lda.alpha'
 
     def finit_beta(self):
+        """Get path to initially trained lda beta file.
+
+        Returns
+        -------
+        str
+            Path to initially trained lda beta file.
+
+        """
         return self.prefix + 'train_out/' + 'initial-lda.beta'
 
     def flda_ss(self):
+        """Get path to initial lda binary file.
+
+        Returns
+        -------
+        str
+            Path to initial lda binary file.
+
+        """
         return self.prefix + 'train_out/' + 'initial-lda-ss.dat'
 
     def fcorpustxt(self):
+        """Get path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to multiple train binary file.
+
+        """
         return self.prefix + 'train-mult.dat'
 
     def fcorpus(self):
+        """Get path to corpus file.
+
+        Returns
+        -------
+        str
+            Path to corpus file.
+
+        """
         return self.prefix + 'train'
 
     def ftimeslices(self):
+        """Get path to time slices binary file.
+
+        Returns
+        -------
+        str
+            Path to time slices binary file.
+
+        """
         return self.prefix + 'train-seq.dat'
 
     def convert_input(self, corpus, time_slices):
-        """
-        Serialize documents in LDA-C format to a temporary text file,.
+        """Convert corpus into LDA-C format by :class:`~gensim.corpora.bleicorpus.BleiCorpus` and save to temp file.
+        Path to temporary file produced by :meth:`~gensim.models.wrappers.dtmmodel.DtmModel.ftimeslices`.
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, float)
+            Corpus in BoW format.
+        time_slices : list of int
+            Sequence of timestamps.
 
         """
         logger.info("serializing temporary corpus to %s", self.fcorpustxt())
@@ -183,8 +326,19 @@ class DtmModel(utils.SaveLoad):
                 fout.write(utils.to_utf8(str(sl) + "\n"))
 
     def train(self, corpus, time_slices, mode, model):
-        """
-        Train DTM model using specified corpus and time slices.
+        """Train DTM model.
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, int)
+            Collection of texts in BoW format.
+        time_slices : list of int
+            Sequence of timestamps.
+        mode : {'fit', 'time'}, optional
+            Controls the mode of the mode: 'fit' is for training, 'time' for analyzing documents through time
+            according to a DTM, basically a held out set.
+        model : {'fixed', 'dtm'}, optional
+            Control model that will be runned: 'fixed' is for DIM and 'dtm' for DTM.
 
         """
         self.convert_input(corpus, time_slices)
@@ -249,14 +403,47 @@ class DtmModel(utils.SaveLoad):
                 self.influences_time.append(influence)
 
     def print_topics(self, num_topics=10, times=5, num_words=10):
+        """Alias for :meth:`~gensim.models.wrappers.dtmmodel.DtmModel.show_topics`.
+
+        Parameters
+        ----------
+        num_topics : int, optional
+            Number of topics to return, set `-1` to get all topics.
+        times : int, optional
+            Number of times.
+        num_words : int, optional
+            Number of words.
+
+        Returns
+        -------
+        list of str
+            Topics as a list of strings
+
+        """
         return self.show_topics(num_topics, times, num_words, log=True)
 
     def show_topics(self, num_topics=10, times=5, num_words=10, log=False, formatted=True):
-        """
-        Print the `num_words` most probable words for `num_topics` number of topics at 'times' time slices.
-        Set `topics=-1` to print all topics.
+        """Get the `num_words` most probable words for `num_topics` number of topics at 'times' time slices.
 
-        Set `formatted=True` to return the topics as a list of strings, or `False` as lists of (weight, word) pairs.
+        Parameters
+        ----------
+        num_topics : int, optional
+            Number of topics to return, set `-1` to get all topics.
+        times : int, optional
+            Number of times.
+        num_words : int, optional
+            Number of words.
+        log : bool, optional
+            THIS PARAMETER WILL BE IGNORED.
+        formatted : bool, optional
+            If `True` - return the topics as a list of strings, otherwise as lists of (weight, word) pairs.
+
+        Returns
+        -------
+        list of str
+            Topics as a list of strings (if formatted=True) **OR**
+        list of (float, str)
+            Topics as list of (weight, word) pairs (if formatted=False)
 
         """
         if num_topics < 0 or num_topics >= self.num_topics:
@@ -284,16 +471,27 @@ class DtmModel(utils.SaveLoad):
         return shown
 
     def show_topic(self, topicid, time, topn=50, num_words=None):
-        """
-        Return `num_words` most probable words for the given `topicid`, as a list of
-        `(word_probability, word)` 2-tuples.
+        """Get `num_words` most probable words for the given `topicid`.
+
+        Parameters
+        ----------
+        topicid : int
+            Id of topic.
+        time : int
+            Timestamp.
+        topn : int, optional
+            Top number of topics that you'll receive.
+        num_words : int, optional
+            DEPRECATED PARAMETER, use `topn` instead.
+
+        Returns
+        -------
+        list of (float, str)
+            Sequence of probable words, as a list of `(word_probability, word)`.
 
         """
         if num_words is not None:  # deprecated num_words is used
-            logger.warning(
-                "The parameter num_words for show_topic() would be deprecated in the updated version. "
-                "Please use topn instead."
-            )
+            warnings.warn("The parameter `num_words` is deprecated, will be removed in 4.0.0, use `topn` instead.")
             topn = num_words
 
         topics = self.lambda_[:, :, time]
@@ -308,21 +506,58 @@ class DtmModel(utils.SaveLoad):
         return beststr
 
     def print_topic(self, topicid, time, topn=10, num_words=None):
-        """Return the given topic, formatted as a string."""
+        """Get the given topic, formatted as a string.
+
+        Parameters
+        ----------
+        topicid : int
+            Id of topic.
+        time : int
+            Timestamp.
+        topn : int, optional
+            Top number of topics that you'll receive.
+        num_words : int, optional
+            DEPRECATED PARAMETER, use `topn` instead.
+
+        Returns
+        -------
+        str
+            The given topic in string format, like '0.132*someword + 0.412*otherword + ...'.
+
+        """
         if num_words is not None:  # deprecated num_words is used
-            warnings.warn(
-                "The parameter num_words for print_topic() would be deprecated in the updated version. "
-                "Please use topn instead."
-            )
+            warnings.warn("The parameter `num_words` is deprecated, will be removed in 4.0.0, use `topn` instead.")
             topn = num_words
 
         return ' + '.join(['%.3f*%s' % v for v in self.show_topic(topicid, time, topn)])
 
     def dtm_vis(self, corpus, time):
-        """
-        returns term_frequency, vocab, doc_lengths, topic-term distributions and doc_topic distributions, specified by pyLDAvis format.
-        all of these are needed to visualise topics for DTM for a particular time-slice via pyLDAvis.
-        input parameter is the year to do the visualisation.
+        """Get data specified by pyLDAvis format.
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, float)
+            Collection of texts in BoW format.
+        time : int
+            Sequence of timestamp.
+
+        Notes
+        -----
+        All of these are needed to visualise topics for DTM for a particular time-slice via pyLDAvis.
+
+        Returns
+        -------
+        doc_topic : numpy.ndarray
+            Document-topic proportions.
+        topic_term : numpy.ndarray
+            Calculated term of topic suitable for pyLDAvis format.
+        doc_lengths : list of int
+            Length of each documents in corpus.
+        term_frequency : numpy.ndarray
+            Frequency of each word from vocab.
+        vocab : list of str
+            List of words from docpus.
+
         """
         topic_term = np.exp(self.lambda_[:, :, time]) / np.exp(self.lambda_[:, :, time]).sum()
         topic_term *= self.num_topics
@@ -342,12 +577,26 @@ class DtmModel(utils.SaveLoad):
         return doc_topic, topic_term, doc_lengths, term_frequency, vocab
 
     def dtm_coherence(self, time, num_words=20):
-        """
-        returns all topics of a particular time-slice without probabilitiy values for it to be used
-        for either "u_mass" or "c_v" coherence.
-        TODO:
-            because of print format right now can only return for 1st time-slice.
-            should we fix the coherence printing or make changes to the print statements to mirror DTM python?
+        """Get all topics of a particular time-slice without probability values for it to be used.
+        For either "u_mass" or "c_v" coherence.
+
+        Parameters
+        ----------
+        num_words : int
+            Number of words.
+        time : int
+            Timestamp
+
+        Returns
+        -------
+        coherence_topics : list of list of str
+            All topics of a particular time-slice without probability values for it to be used.
+
+        Warnings
+        --------
+        TODO: because of print format right now can only return for 1st time-slice, should we fix the coherence
+        printing or make changes to the print statements to mirror DTM python?
+
         """
         coherence_topics = []
         for topic_no in range(0, self.num_topics):
