@@ -5,26 +5,39 @@
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
 
 
-"""
-Python wrapper for Latent Dirichlet Allocation (LDA) from MALLET, the Java topic modelling
-toolkit [1]_.
+"""Python wrapper for `Latent Dirichlet Allocation (LDA) <https://en.wikipedia.org/wiki/Latent_Dirichlet_allocation>`_
+from `MALLET, the Java topic modelling toolkit <http://mallet.cs.umass.edu/>`_
 
-This module allows both LDA model estimation from a training corpus and inference of topic
-distribution on new, unseen documents, using an (optimized version of) collapsed
-gibbs sampling from MALLET.
+This module allows both LDA model estimation from a training corpus and inference of topic distribution on new,
+unseen documents, using an (optimized version of) collapsed gibbs sampling from MALLET.
 
-MALLET's LDA training requires O(#corpus_words) of memory, keeping the entire corpus in RAM.
-If you find yourself running out of memory, either decrease the `workers` constructor
-parameter, or use `LdaModel` which needs only O(1) memory.
+Notes
+-----
+MALLET's LDA training requires :math:O(#corpus_words) of memory, keeping the entire corpus in RAM.
+If you find yourself running out of memory, either decrease the `workers` constructor parameter,
+or use :class:`gensim.models.ldamodel.LdaModel` or :class:`gensim.models.ldamulticore.LdaMulticore`
+which needs only :math:`O(1)` memory.
+The wrapped model can NOT be updated with new documents for online training -- use
+:class:`~gensim.models.ldamodel.LdaModel` or :class:`~gensim.models.ldamulticore.LdaMulticore` for that.
 
-The wrapped model can NOT be updated with new documents for online training -- use gensim's `LdaModel` for that.
+Installation
+------------
+Use `official guide <http://mallet.cs.umass.edu/download.php>`_ or this one ::
 
-Example:
+    sudo apt-get install default-jdk
+    sudo apt-get install ant
+    git clone git@github.com:mimno/Mallet.git
+    cd Mallet/
+    ant
 
-    >>> model = gensim.models.wrappers.LdaMallet('/Users/kofola/mallet-2.0.7/bin/mallet', corpus=my_corpus, num_topics=20, id2word=dictionary)
-    >>> print model[my_vector]  # print LDA topics of a document
-
-.. [1] http://mallet.cs.umass.edu/
+Examples
+--------
+>>> from gensim.test.utils import common_corpus, common_dictionary
+>>> from gensim.models.wrappers import LdaMallet
+>>>
+>>> path_to_mallet_binary = "/path/to/mallet/binary"
+>>> model = LdaMallet(path_to_mallet_binary, corpus=common_corpus, num_topics=20, id2word=common_dictionary)
+>>> vector = model[common_corpus[0]]  # LDA topics of a documents
 
 """
 
@@ -32,6 +45,7 @@ Example:
 import logging
 import os
 import random
+import warnings
 import tempfile
 import xml.etree.ElementTree as et
 import zipfile
@@ -48,30 +62,44 @@ logger = logging.getLogger(__name__)
 
 
 class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
-    """
-    Class for LDA training using MALLET. Communication between MALLET and Python
-    takes place by passing around data files on disk and calling Java with subprocess.call().
+    """Python wrapper for LDA using `MALLET <http://mallet.cs.umass.edu/>`_.
+
+    Communication between MALLET and Python takes place by passing around data files on disk
+    and calling Java with subprocess.call().
+
+    Warnings
+    --------
+    This is **only** python wrapper for `MALLET LDA <http://mallet.cs.umass.edu/>`_,
+    you need to install original implementation first and pass the path to binary to ``mallet_path``.
 
     """
-
     def __init__(self, mallet_path, corpus=None, num_topics=100, alpha=50, id2word=None, workers=4, prefix=None,
                  optimize_interval=0, iterations=1000, topic_threshold=0.0):
         """
-        `mallet_path` is path to the mallet executable, e.g. `/home/kofola/mallet-2.0.7/bin/mallet`.
 
-        `corpus` is a gensim corpus, aka a stream of sparse document vectors.
-
-        `id2word` is a mapping between tokens ids and token.
-
-        `workers` is the number of threads, for parallel training.
-
-        `prefix` is the string prefix under which all data files will be stored; default: system temp + random filename prefix.
-
-        `optimize_interval` optimize hyperparameters every N iterations (sometimes leads to Java exception; 0 to switch off hyperparameter optimization).
-
-        `iterations` is the number of sampling iterations.
-
-        `topic_threshold` is the threshold of the probability above which we consider a topic. This is basically for sparse topic distribution.
+        Parameters
+        ----------
+        mallet_path : str
+            Path to the mallet binary, e.g. `/home/username/mallet-2.0.7/bin/mallet`.
+        corpus : iterable of iterable of (int, int), optional
+            Collection of texts in BoW format.
+        num_topics : int, optional
+            Number of topics.
+        alpha : int, optional
+            Alpha parameter of LDA.
+        id2word : :class:`~gensim.corpora.dictionary.Dictionary`, optional
+            Mapping between tokens ids and words from corpus, if not specified - will be inferred from `corpus`.
+        workers : int, optional
+            Number of threads that will be used for training.
+        prefix : str, optional
+            Prefix for produced temporary files.
+        optimize_interval : int, optional
+            Optimize hyperparameters every `optimize_interval` iterations
+            (sometimes leads to Java exception 0 to switch off hyperparameter optimization).
+        iterations : int, optional
+            Number of training iterations.
+        topic_threshold : float, optional
+            Threshold of the probability above which we consider a topic.
 
         """
         self.mallet_path = mallet_path
@@ -98,31 +126,96 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
             self.train(corpus)
 
     def finferencer(self):
+        """Get path to inferencer.mallet file.
+
+        Returns
+        -------
+        str
+            Path to inferencer.mallet file.
+
+        """
         return self.prefix + 'inferencer.mallet'
 
     def ftopickeys(self):
+        """Get path to topic keys text file.
+
+        Returns
+        -------
+        str
+            Path to topic keys text file.
+
+        """
         return self.prefix + 'topickeys.txt'
 
     def fstate(self):
+        """Get path to temporary file.
+
+        Returns
+        -------
+        str
+            Path to file.
+
+        """
         return self.prefix + 'state.mallet.gz'
 
     def fdoctopics(self):
+        """Get path to document topic text file.
+
+        Returns
+        -------
+        str
+            Path to document topic text file.
+
+        """
         return self.prefix + 'doctopics.txt'
 
     def fcorpustxt(self):
+        """Get path to corpus text file.
+
+        Returns
+        -------
+        str
+            Path to corpus text file.
+
+        """
         return self.prefix + 'corpus.txt'
 
     def fcorpusmallet(self):
+        """Get path to corpus.mallet file.
+
+        Returns
+        -------
+        str
+            Path to corpus.mallet file.
+
+        """
         return self.prefix + 'corpus.mallet'
 
     def fwordweights(self):
+        """Get path to word weight file.
+
+        Returns
+        -------
+        str
+            Path to word weight file.
+
+        """
         return self.prefix + 'wordweights.txt'
 
     def corpus2mallet(self, corpus, file_like):
-        """
-        Write out `corpus` in a file format that MALLET understands: one document per line:
+        """Convert `corpus` to Mallet format and write it to `file_like` descriptor.
+
+        Format ::
+
+            document id[SPACE]label (not used)[SPACE]whitespace delimited utf8-encoded tokens[NEWLINE]
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, int)
+            Collection of texts in BoW format.
+        file_like : file-like object
+            Opened file.
 
-          document id[SPACE]label (not used)[SPACE]whitespace delimited utf8-encoded tokens[NEWLINE]
         """
         for docno, doc in enumerate(corpus):
             if self.id2word:
@@ -132,9 +225,16 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
             file_like.write(utils.to_utf8("%s 0 %s\n" % (docno, ' '.join(tokens))))
 
     def convert_input(self, corpus, infer=False, serialize_corpus=True):
-        """
-        Serialize documents (lists of unicode tokens) to a temporary text file,
-        then convert that text file to MALLET format `outfile`.
+        """Convert corpus to Mallet format and save it to a temporary text file.
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, int)
+            Collection of texts in BoW format.
+        infer : bool, optional
+            ...
+        serialize_corpus : bool, optional
+            ...
 
         """
         if serialize_corpus:
@@ -143,7 +243,10 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
                 self.corpus2mallet(corpus, fout)
 
         # convert the text file above into MALLET's internal format
-        cmd = self.mallet_path + " import-file --preserve-case --keep-sequence --remove-stopwords --token-regex \"\S+\" --input %s --output %s"
+        cmd = \
+            self.mallet_path + \
+            " import-file --preserve-case --keep-sequence " \
+            "--remove-stopwords --token-regex \"\S+\" --input %s --output %s"
         if infer:
             cmd += ' --use-pipe-from ' + self.fcorpusmallet()
             cmd = cmd % (self.fcorpustxt(), self.fcorpusmallet() + '.infer')
@@ -153,6 +256,14 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
         check_output(args=cmd, shell=True)
 
     def train(self, corpus):
+        """Train Mallet LDA.
+
+        Parameters
+        ----------
+        corpus : iterable of iterable of (int, int)
+            Corpus in BoW format
+
+        """
         self.convert_input(corpus, infer=False)
         cmd = self.mallet_path + ' train-topics --input %s --num-topics %s  --alpha %s --optimize-interval %s '\
             '--num-threads %s --output-state %s --output-doc-topics %s --output-topic-keys %s '\
@@ -167,17 +278,37 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
         check_output(args=cmd, shell=True)
         self.word_topics = self.load_word_topics()
         # NOTE - we are still keeping the wordtopics variable to not break backward compatibility.
-        # word_topics has replaced wordtopics throughout the code; wordtopics just stores the values of word_topics when train is called.
+        # word_topics has replaced wordtopics throughout the code;
+        # wordtopics just stores the values of word_topics when train is called.
         self.wordtopics = self.word_topics
 
     def __getitem__(self, bow, iterations=100):
+        """Get vector for document(s).
+
+        Parameters
+        ----------
+        bow : {list of (int, int), iterable of list of (int, int)}
+            Document (or corpus) in BoW format.
+        iterations : int, optional
+            Number of iterations that will be used for inferring.
+
+        Returns
+        -------
+        list of (int, float)
+            LDA vector for document as sequence of (topic_id, topic_probability) **OR**
+        list of list of (int, float)
+            LDA vectors for corpus in same format.
+
+        """
         is_corpus, corpus = utils.is_corpus(bow)
         if not is_corpus:
             # query is a single document => make a corpus out of it
             bow = [bow]
 
         self.convert_input(bow, infer=True)
-        cmd = self.mallet_path + ' infer-topics --input %s --inferencer %s --output-doc-topics %s --num-iterations %s --doc-topics-threshold %s'
+        cmd = \
+            self.mallet_path + ' infer-topics --input %s --inferencer %s ' \
+                               '--output-doc-topics %s --num-iterations %s --doc-topics-threshold %s'
         cmd = cmd % (
             self.fcorpusmallet() + '.infer', self.finferencer(),
             self.fdoctopics() + '.infer', iterations, self.topic_threshold
@@ -188,6 +319,14 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
         return result if is_corpus else result[0]
 
     def load_word_topics(self):
+        """Load words X topics matrix from :meth:`gensim.models.wrappers.ldamallet.LdaMallet.fstate` file.
+
+        Returns
+        -------
+        numpy.ndarray
+            Matrix words X topics.
+
+        """
         logger.info("loading assigned topics from %s", self.fstate())
         word_topics = numpy.zeros((self.num_topics, self.num_terms), dtype=numpy.float64)
         if hasattr(self.id2word, 'token2id'):
@@ -210,28 +349,49 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
         return word_topics
 
     def load_document_topics(self):
-        """
-        Returns:
-            An iterator over the topic distribution of training corpus, by reading
-            the doctopics.txt generated during training.
+        """Load document topics from :meth:`gensim.models.wrappers.ldamallet.LdaMallet.fdoctopics` file.
+        Shortcut for :meth:`gensim.models.wrappers.ldamallet.LdaMallet.read_doctopics`.
+
+        Returns
+        -------
+        iterator of list of (int, float)
+            Sequence of LDA vectors for documents.
+
         """
         return self.read_doctopics(self.fdoctopics())
 
     def get_topics(self):
-        """
-        Returns:
-            np.ndarray: `num_topics` x `vocabulary_size` array of floats which represents
-            the term topic matrix learned during inference.
+        """Get topics X words matrix.
+
+        Returns
+        -------
+        numpy.ndarray
+            Topics X words matrix, shape `num_topics` x `vocabulary_size`.
+
         """
         topics = self.word_topics
         return topics / topics.sum(axis=1)[:, None]
 
     def show_topics(self, num_topics=10, num_words=10, log=False, formatted=True):
-        """
-        Print the `num_words` most probable words for `num_topics` number of topics.
-        Set `num_topics=-1` to print all topics.
+        """Get the `num_words` most probable words for `num_topics` number of topics.
 
-        Set `formatted=True` to return the topics as a list of strings, or `False` as lists of (weight, word) pairs.
+        Parameters
+        ----------
+        num_topics : int, optional
+            Number of topics to return, set `-1` to get all topics.
+        num_words : int, optional
+            Number of words.
+        log : bool, optional
+            If True - write topic with logging too, used for debug proposes.
+        formatted : bool, optional
+            If `True` - return the topics as a list of strings, otherwise as lists of (weight, word) pairs.
+
+        Returns
+        -------
+        list of str
+            Topics as a list of strings (if formatted=True) **OR**
+        list of (float, str)
+            Topics as list of (weight, word) pairs (if formatted=False)
 
         """
         if num_topics < 0 or num_topics >= self.num_topics:
@@ -239,7 +399,8 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
             chosen_topics = range(num_topics)
         else:
             num_topics = min(num_topics, self.num_topics)
-            sort_alpha = self.alpha + 0.0001 * numpy.random.rand(len(self.alpha))  # add a little random jitter, to randomize results around the same alpha
+            # add a little random jitter, to randomize results around the same alpha
+            sort_alpha = self.alpha + 0.0001 * numpy.random.rand(len(self.alpha))
             sorted_topics = list(matutils.argsort(sort_alpha))
             chosen_topics = sorted_topics[: num_topics // 2] + sorted_topics[-num_topics // 2:]
         shown = []
@@ -247,16 +408,32 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
             if formatted:
                 topic = self.print_topic(i, topn=num_words)
             else:
-                topic = self.show_topic(i, num_words=num_words)
+                topic = self.show_topic(i, topn=num_words)
             shown.append((i, topic))
             if log:
                 logger.info("topic #%i (%.3f): %s", i, self.alpha[i], topic)
         return shown
 
     def show_topic(self, topicid, topn=10, num_words=None):
+        """Get `num_words` most probable words for the given `topicid`.
+
+        Parameters
+        ----------
+        topicid : int
+            Id of topic.
+        topn : int, optional
+            Top number of topics that you'll receive.
+        num_words : int, optional
+            DEPRECATED PARAMETER, use `topn` instead.
+
+        Returns
+        -------
+        list of (str, float)
+            Sequence of probable words, as a list of `(word, word_probability)` for `topicid` topic.
+
+        """
         if num_words is not None:  # deprecated num_words is used
-            logger.warning("The parameter num_words for show_topic() would be deprecated in the updated version.")
-            logger.warning("Please use topn instead.")
+            warnings.warn("The parameter `num_words` is deprecated, will be removed in 4.0.0, use `topn` instead.")
             topn = num_words
 
         if self.word_topics is None:
@@ -268,15 +445,20 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
         return beststr
 
     def get_version(self, direc_path):
-        """"
+        """"Get the version of Mallet.
 
-        function to return the version of `mallet`
+        Parameters
+        ----------
+        direc_path : str
+            Path to mallet archive.
+
+        Returns
+        -------
+        str
+            Version of mallet.
 
         """
         try:
-            """
-            Check version of mallet via jar file
-            """
             archive = zipfile.ZipFile(direc_path, 'r')
             if u'cc/mallet/regression/' not in archive.namelist():
                 return '2.0.7'
@@ -293,8 +475,26 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
                 return "Can't parse pom.xml version file"
 
     def read_doctopics(self, fname, eps=1e-6, renorm=True):
-        """
-        Yield document topic vectors from MALLET's "doc-topics" format, as sparse gensim vectors.
+        """Get document topic vectors from MALLET's "doc-topics" format, as sparse gensim vectors.
+
+        Parameters
+        ----------
+        fname : str
+            Path to input file with document topics.
+        eps : float, optional
+            Threshold for probabilities.
+        renorm : bool, optional
+            If True - explicitly re-normalize distribution.
+
+        Raises
+        ------
+        RuntimeError
+            If any line in invalid format.
+
+        Yields
+        ------
+        list of (int, float)
+            LDA vectors for document.
 
         """
         mallet_version = self.get_version(self.mallet_path)
@@ -308,19 +508,25 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
                 # the MALLET doctopic format changed in 2.0.8 to exclude the id,
                 # this handles the file differently dependent on the pattern
                 if len(parts) == 2 * self.num_topics:
-                    doc = [(int(id_), float(weight)) for id_, weight in zip(*[iter(parts)] * 2) if abs(float(weight)) > eps]
+                    doc = [
+                        (int(id_), float(weight)) for id_, weight in zip(*[iter(parts)] * 2)
+                        if abs(float(weight)) > eps
+                    ]
                 elif len(parts) == self.num_topics and mallet_version != '2.0.7':
                     doc = [(id_, float(weight)) for id_, weight in enumerate(parts) if abs(float(weight)) > eps]
                 else:
                     if mallet_version == "2.0.7":
                         """
 
-                            1   1   0   1.0780612802674239  30.005575655428533364   2   0.005575655428533364    1   0.005575655428533364
-                            2   2   0   0.9184413079632608  40.009062076892971008   3   0.009062076892971008    2   0.009062076892971008    1   0.009062076892971008
-                            In the above example there is a mix of the above if and elif statement. There are neither `2*num_topics` nor `num_topics` elements.
-                            It has 2 formats 40.009062076892971008 and 0   1.0780612802674239 which cannot be handled by above if elif.
-                            Also, there are some topics are missing(meaning that the topic is not there) which is another reason why the above if elif
-                            fails even when the `mallet` produces the right results
+                            1   1   0   1.0780612802674239  30.005575655428533364   2   0.005575655428533364
+                            2   2   0   0.9184413079632608  40.009062076892971008   3   0.009062076892971008
+                            In the above example there is a mix of the above if and elif statement.
+                            There are neither `2*num_topics` nor `num_topics` elements.
+                            It has 2 formats 40.009062076892971008 and 0   1.0780612802674239
+                            which cannot be handled by above if elif.
+                            Also, there are some topics are missing(meaning that the topic is not there)
+                            which is another reason why the above if elif fails even when the `mallet`
+                            produces the right results
 
                         """
                         count = 0
@@ -357,23 +563,30 @@ class LdaMallet(utils.SaveLoad, basemodel.BaseTopicModel):
 
 
 def malletmodel2ldamodel(mallet_model, gamma_threshold=0.001, iterations=50):
-    """
-    Function to convert mallet model to gensim LdaModel. This works by copying the
-    training model weights (alpha, beta...) from a trained mallet model into the
-    gensim model.
+    """Convert :class:`~gensim.models.wrappers.ldamallet.LdaMallet` to :class:`~gensim.models.ldamodel.LdaModel`.
 
-    Args:
-        mallet_model : Trained mallet model
-        gamma_threshold : To be used for inference in the new LdaModel.
-        iterations : number of iterations to be used for inference in the new LdaModel.
+    This works by copying the training model weights (alpha, beta...) from a trained mallet model into the gensim model.
+
+    Parameters
+    ----------
+    mallet_model : :class:`~gensim.models.wrappers.ldamallet.LdaMallet`
+        Trained Mallet model
+    gamma_threshold : float, optional
+        To be used for inference in the new LdaModel.
+    iterations : int, optional
+        Number of iterations to be used for inference in the new LdaModel.
+
+    Returns
+    -------
+    :class:`~gensim.models.ldamodel.LdaModel`
+        Gensim native LDA.
 
-    Returns:
-        model_gensim : LdaModel instance; copied gensim LdaModel
     """
     model_gensim = LdaModel(
         id2word=mallet_model.id2word, num_topics=mallet_model.num_topics,
         alpha=mallet_model.alpha, iterations=iterations,
-        gamma_threshold=gamma_threshold
+        gamma_threshold=gamma_threshold,
+        dtype=numpy.float64  # don't loose precision when converting from MALLET
     )
     model_gensim.expElogbeta[:] = mallet_model.wordtopics
     return model_gensim
