@@ -4,55 +4,72 @@
 # Copyright (C) 2015 Dave Challis <dave@suicas.net>
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
 
-"""
-Python wrapper around Vowpal Wabbit's Latent Dirichlet Allocation (LDA)
-implementation [1]_.
+"""Python wrapper for `Vowpal Wabbit's Latent Dirichlet Allocation <https://github.com/JohnLangford/vowpal_wabbit/>`_.
 
-This uses Matt Hoffman's online algorithm, for LDA [2]_, i.e. the same
-algorithm that Gensim's LdaModel is based on.
+This uses `Matt Hoffman's online algorithm
+<http://papers.nips.cc/paper/3902-online-learning-for-latent-dirichlet-allocation.pdf>`_, i.e. the same algorithm
+that Gensim's :class:`~gensim.models.ldamodel.LdaModel` is based on.
 
-Note: Currently working and tested with Vowpal Wabbit versions 7.10 to 8.1.1.
-Vowpal Wabbit's API isn't currently stable, so this may or may not work with
-older/newer versions. The aim will be to ensure this wrapper always works with
+Installation
+------------
+Use `official guide <https://github.com/JohnLangford/vowpal_wabbit>`_ or this one ::
+
+    git clone https://github.com/JohnLangford/vowpal_wabbit.git
+    cd vowpal_wabbit
+    make
+    make test
+    sudo make install
+
+Warnings
+--------
+Currently working and tested with Vowpal Wabbit versions 7.10 to 8.1.1. Vowpal Wabbit's API isn't currently stable,
+so this may or may not work with older/newer versions. The aim will be to ensure this wrapper always works with
 the latest release of Vowpal Wabbit.
 
-Tested with python 2.6, 2.7, and 3.4.
 
-Example:
+Examples
+--------
 
-    >>> # train model
-    >>> lda = gensim.models.wrappers.LdaVowpalWabbit('/usr/local/bin/vw',
-                                                     corpus=corpus,
-                                                     num_topics=20,
-                                                     id2word=dictionary)
+Train model
 
-    >>> # update an existing model
-    >>> lda.update(another_corpus)
+>>> from gensim.test.utils import common_corpus, common_dictionary
+>>> from gensim.models.wrappers import LdaVowpalWabbit
+>>>
+>>> path_to_wv_binary = "/path/to/vw/binary"
+>>> model = LdaVowpalWabbit(path_to_wv_binary, corpus=common_corpus, num_topics=20, id2word=common_dictionary)
 
-    >>> # get topic probability distributions for a document
-    >>> print(lda[doc_bow])
+Update existing model
 
-    >>> # print 10 topics
-    >>> print(lda.print_topics())
+>>> another_corpus = [[(1, 1), (2, 1)], [(3, 5)]]
+>>> model.update(another_corpus)
 
-    >>> # save/load the trained model:
+Get topic probability distributions for a document
 
-    >>> lda.save('vw_lda.model')
-    >>> lda = gensim.models.wrappers.LdaVowpalWabbit.load('vw_lda.model')
+>>> document_bow = [(1, 1)]
+>>> print(model[document_bow])
 
-    >>> # get bound on log perplexity for given test set
-    >>> print(lda.log_perpexity(test_corpus))
+Print topics
 
-Vowpal Wabbit works on files, so this wrapper maintains a temporary directory
-while it's around, reading/writing there as necessary.
+>>> print(model.print_topics())
 
-Output from Vowpal Wabbit is logged at either INFO or DEBUG levels, enable
-logging to view this.
+Save/load the trained model
+
+>>> from gensim.test.utils import get_tmpfile
+>>>
+>>> temp_path = get_tmpfile("vw_lda.model")
+>>> model.save(temp_path)
+>>>
+>>> loaded_lda = LdaVowpalWabbit.load(temp_path)
+
+Calculate log-perplexoty on given corpus
+
+>>> another_corpus = [[(1, 1), (2, 1)], [(3, 5)]]
+>>> print(model.log_perpexity(another_corpus))
+
+Vowpal Wabbit works on files, so this wrapper maintains a temporary directory while it's around,
+reading/writing there as necessary.
 
-.. [1] https://github.com/JohnLangford/vowpal_wabbit/wiki
-.. [2] http://www.cs.princeton.edu/~mdhoffma/
 """
-
 from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
@@ -72,66 +89,70 @@ logger = logging.getLogger(__name__)
 
 
 class LdaVowpalWabbit(utils.SaveLoad):
-    """Class for LDA training using Vowpal Wabbit's online LDA. Communication
-    between Vowpal Wabbit and Python takes place by passing around data files
-    on disk and calling the 'vw' binary with the subprocess module.
-    """
+    """Python wrapper using `Vowpal Wabbit's online LDA <https://github.com/JohnLangford/vowpal_wabbit/>`_.
 
+    Communication between Vowpal Wabbit and Python takes place by passing around data files
+    on disk and calling the 'vw' binary with the subprocess module.
+
+    Warnings
+    --------
+    This is **only** python wrapper for `Vowpal Wabbit's online LDA <https://github.com/JohnLangford/vowpal_wabbit/>`_,
+    you need to install original implementation first and pass the path to binary to ``vw_path``.
+
+    """
     def __init__(self, vw_path, corpus=None, num_topics=100, id2word=None,
                  chunksize=256, passes=1, alpha=0.1, eta=0.1, decay=0.5,
                  offset=1, gamma_threshold=0.001, random_seed=None,
                  cleanup_files=True, tmp_prefix='tmp'):
-        """`vw_path` is the path to Vowpal Wabbit's 'vw' executable.
+        """
 
-        `corpus` is an iterable training corpus. If given, training will
-        start immediately, otherwise the model is left untrained (presumably
-        because you want to call `update()` manually).
+        Parameters
+        ----------
+        vw_path : str
+            Path to Vowpal Wabbit's binary.
+        corpus : iterable of list of (int, int), optional
+            Collection of texts in BoW format. If given, training will start immediately,
+            otherwise, you should call :meth:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit.train` or
+            :meth:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit.update` manually for training.
+        num_topics : int, optional
+            Number of requested latent topics to be extracted from the training corpus.
+            Corresponds to VW's ``--lda <num_topics>`` argument.
+        id2word : :class:`~gensim.corpora.dictionary.Dictionary`, optional
+            Mapping from word ids (integers) to words (strings).
+        chunksize : int, optional
+            Number of documents examined in each batch.
+            Corresponds to VW's ``--minibatch <batch_size>`` argument.
+        passes : int, optional
+            Number of passes over the dataset to use.
+            Corresponds to VW's ``--passes <passes>`` argument.
+        alpha : float, optional
+            Float effecting sparsity of per-document topic weights.
+            This is applied symmetrically, and should be set higher to when documents are thought to look more similar.
+            Corresponds to VW's ``--lda_alpha <alpha>`` argument.
+        eta : float, optional
+            Affects the sparsity of topic distributions.
+            This is applied symmetrically, and should be set higher when topics
+            are thought to look more similar.
+            Corresponds to VW's ``--lda_rho <rho>`` argument.
+        decay : float, optional
+            Learning rate decay, affects how quickly learnt values are forgotten.
+            Should be set to a value between 0.5 and 1.0 to guarantee convergence.
+            Corresponds to VW's ``--power_t <tau>`` argument.
+        offset: int, optional
+            Learning offset, set to higher values to slow down learning on early iterations of the algorithm.
+            Corresponds to VW's ``--initial_t <tau>`` argument.
+        gamma_threshold : float, optional
+            Affects when learning loop will be broken out of, higher values will result in earlier loop completion.
+            Corresponds to VW's ``--epsilon <eps>`` argument.
+        random_seed : int, optional
+            Sets random seed when learning.
+            Corresponds to VW's ``--random_seed <seed>`` argument.
+        cleanup_files : bool, optional
+            Whether or not to delete temporary directory and files used by this wrapper.
+            Setting to False can be useful for debugging, or for re-using Vowpal Wabbit files elsewhere.
+        tmp_prefix : str, optional
+            To prefix temporary working directory name.
 
-        `num_topics` is the number of requested latent topics to be extracted
-        from the training corpus.
-        Corresponds to VW's '--lda <num_topics>' argument.
-
-        `id2word` is a mapping from word ids (integers) to words (strings).
-        It is used to determine the vocabulary size, as well as for debugging
-        and topic printing.
-
-        `chunksize` is the number of documents examined in each batch.
-        Corresponds to VW's '--minibatch <batch_size>' argument.
-
-        `passes` is the number of passes over the dataset to use.
-        Corresponds to VW's '--passes <passes>' argument.
-
-        `alpha` is a float effecting sparsity of per-document topic weights.
-        This is applied symmetrically, and should be set higher to when
-        documents are thought to look more similar.
-        Corresponds to VW's '--lda_alpha <alpha>' argument.
-
-        `eta` is a float which affects the sparsity of topic distributions.
-        This is applied symmetrically, and should be set higher when topics
-        are thought to look more similar.
-        Corresponds to VW's '--lda_rho <rho>' argument.
-
-        `decay` learning rate decay, affects how quickly learnt values
-        are forgotten. Should be set to a value between 0.5 and 1.0 to
-        guarantee convergence.
-        Corresponds to VW's '--power_t <tau>' argument.
-
-        `offset` integer learning offset, set to higher values to slow down
-        learning on early iterations of the algorithm.
-        Corresponds to VW's '--initial_t <tau>' argument.
-
-        `gamma_threshold` affects when learning loop will be broken out of,
-        higher values will result in earlier loop completion.
-        Corresponds to VW's '--epsilon <eps>' argument.
-
-        `random_seed` sets Vowpal Wabbit's random seed when learning.
-        Corresponds to VW's '--random_seed <seed>' argument.
-
-        `cleanup_files` whether or not to delete temporary directory and files
-        used by this wrapper. Setting to False can be useful for debugging,
-        or for re-using Vowpal Wabbit files elsewhere.
-
-        `tmp_prefix` used to prefix temporary working directory name.
         """
         # default parameters are taken from Vowpal Wabbit's defaults, and
         # parameter names changed to match Gensim's LdaModel where possible
@@ -183,7 +204,14 @@ class LdaVowpalWabbit(utils.SaveLoad):
             self.train(corpus)
 
     def train(self, corpus):
-        """Clear any existing model state, and train on given corpus."""
+        """Clear any existing model state, and train on given `corpus`.
+
+        Parameters
+        ----------
+        corpus : iterable of list of (int, int)
+            Collection of texts in BoW format.
+
+        """
         logger.debug('Training new model from corpus')
 
         # reset any existing offset, model, or topics generated
@@ -200,7 +228,14 @@ class LdaVowpalWabbit(utils.SaveLoad):
         self.offset += corpus_size
 
     def update(self, corpus):
-        """Update existing model (if any) on corpus."""
+        """Update existing model with `corpus`.
+
+        Parameters
+        ----------
+        corpus : iterable of list of (int, int)
+            Collection of texts in BoW format.
+
+        """
         if not os.path.exists(self._model_filename):
             return self.train(corpus)
 
@@ -219,9 +254,18 @@ class LdaVowpalWabbit(utils.SaveLoad):
         self.offset += corpus_size
 
     def log_perplexity(self, chunk):
-        """Return per-word lower bound on log perplexity.
+        """Get per-word lower bound on log perplexity.
+
+        Parameters
+        ----------
+        chunk : iterable of list of (int, int)
+            Collection of texts in BoW format.
+
+        Returns
+        -------
+        bound : float
+            Per-word lower bound on log perplexity.
 
-        Also logs this and perplexity at INFO level.
         """
         vw_data = self._predict(chunk)[1]
         corpus_words = sum(cnt for document in chunk for _, cnt in document)
@@ -233,19 +277,57 @@ class LdaVowpalWabbit(utils.SaveLoad):
         return bound
 
     def get_topics(self):
-        """
-        Returns:
-            np.ndarray: `num_topics` x `vocabulary_size` array of floats which represents
-            the term topic matrix learned during inference.
+        """Get topics X words matrix.
+
+        Returns
+        -------
+        numpy.ndarray
+            `num_topics` x `vocabulary_size` array of floats which represents the learned term topic matrix.
+
         """
         topics = self._get_topics()
         return topics / topics.sum(axis=1)[:, None]
 
     def print_topics(self, num_topics=10, num_words=10):
+        """Alias for :meth:`~gensim.models.wrappers.dtmmodel.DtmModel.show_topics`.
+
+        Parameters
+        ----------
+        num_topics : int, optional
+            Number of topics to return, set `-1` to get all topics.
+        num_words : int, optional
+            Number of words.
+
+        Returns
+        -------
+        list of str
+            Topics as a list of strings
+
+        """
         return self.show_topics(num_topics, num_words, log=True)
 
-    def show_topics(self, num_topics=10, num_words=10,
-                    log=False, formatted=True):
+    def show_topics(self, num_topics=10, num_words=10, log=False, formatted=True):
+        """Get the `num_words` most probable words for `num_topics` number of topics.
+
+        Parameters
+        ----------
+        num_topics : int, optional
+            Number of topics to return, set `-1` to get all topics.
+        num_words : int, optional
+            Number of words.
+        log : bool, optional
+            If True - will write topics with logger.
+        formatted : bool, optional
+            If `True` - return the topics as a list of strings, otherwise as lists of (weight, word) pairs.
+
+        Returns
+        -------
+        list of str
+            Topics as a list of strings (if formatted=True) **OR**
+        list of (float, str)
+            Topics as list of (weight, word) pairs (if formatted=False)
+
+        """
         if num_topics < 0 or num_topics >= self.num_topics:
             num_topics = self.num_topics
         else:
@@ -268,17 +350,53 @@ class LdaVowpalWabbit(utils.SaveLoad):
         return shown
 
     def print_topic(self, topicid, topn=10):
-        return ' + '.join(['{0:.3f}*{1}'.format(v[0], v[1])
-                           for v in self.show_topic(topicid, topn)])
+        """Get text representation of topic.
+
+        Parameters
+        ----------
+        topicid : int
+            Id of topic.
+        topn : int, optional
+            Top number of words in topic.
+
+        Returns
+        -------
+        str
+            Topic `topicid` in text representation.
+
+        """
+        return ' + '.join(['{0:.3f}*{1}'.format(v[0], v[1]) for v in self.show_topic(topicid, topn)])
 
     def show_topic(self, topicid, topn=10):
+        """Get `num_words` most probable words for the given `topicid`.
+
+        Parameters
+        ----------
+        topicid : int
+            Id of topic.
+        topn : int, optional
+            Top number of topics that you'll receive.
+
+        Returns
+        -------
+        list of (str, float)
+            Sequence of probable words, as a list of `(word, word_probability)` for `topicid` topic.
+
+        """
         topics = self._get_topics()
         topic = topics[topicid]
         bestn = matutils.argsort(topic, topn, reverse=True)
         return [(topic[t_id], self.id2word[t_id]) for t_id in bestn]
 
     def save(self, fname, *args, **kwargs):
-        """Serialise this model to file with given name."""
+        """Save model to file.
+
+        Parameters
+        ----------
+        fname : str
+            Path to output file.
+
+        """
         if os.path.exists(self._model_filename):
             # Vowpal Wabbit uses its own binary model file, read this into
             # variable before serialising this object - keeps all data
@@ -299,7 +417,14 @@ class LdaVowpalWabbit(utils.SaveLoad):
 
     @classmethod
     def load(cls, fname, *args, **kwargs):
-        """Load LDA model from file with given name."""
+        """Load model from `fname`.
+
+        Parameters
+        ----------
+        fname : str
+            Path to file with :class:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit`.
+
+        """
         lda_vw = super(LdaVowpalWabbit, cls).load(fname, *args, **kwargs)
         lda_vw._init_temp_dir(prefix=lda_vw.tmp_prefix)
 
@@ -326,12 +451,26 @@ class LdaVowpalWabbit(utils.SaveLoad):
             shutil.rmtree(self.tmp_dir)
 
     def _init_temp_dir(self, prefix='tmp'):
-        """Create a working temporary directory with given prefix."""
+        """Create a working temporary directory with given prefix.
+
+        Parameters
+        ----------
+        prefix : str
+            Prefix of the temporary directory.
+
+        """
         self.tmp_dir = tempfile.mkdtemp(prefix=prefix)
         logger.info('using %s as temp dir', self.tmp_dir)
 
     def _get_vw_predict_command(self, corpus_size):
-        """Get list of command line arguments for running prediction."""
+        """Get list of command line arguments for running prediction.
+
+        Parameters
+        ----------
+        corpus_size : int
+            Size of the corpus.
+
+        """
         cmd = [
             self.vw_path,
             '--testonly',  # don't update model with this data
@@ -350,8 +489,18 @@ class LdaVowpalWabbit(utils.SaveLoad):
     def _get_vw_train_command(self, corpus_size, update=False):
         """Get list of command line arguments for running model training.
 
-        If 'update' is set to True, this specifies that we're further training
-        an existing model.
+        Parameters
+        ----------
+        corpus_size : int
+            Size of corpus.
+        update : bool
+            Set `True` to further train an existing model.
+
+        Returns
+        -------
+        list of str
+            Sequence of all training parameters.
+
         """
         cmd = [
             self.vw_path,
@@ -385,16 +534,24 @@ class LdaVowpalWabbit(utils.SaveLoad):
         return cmd
 
     def _get_vw_update_command(self, corpus_size):
-        """Get list of command line arguments to update a model."""
+        """Get list of command line arguments to update a model.
+        Alias for :meth:`~gensim.models.wrappers.dtmmodel.DtmModel._get_vw_train_command`
+
+        Parameters
+        ----------
+        corpus_size : int
+            Size of the corpus.
+
+        Returns
+        -------
+        list of str
+            Sequence of all training parameters.
+
+        """
         return self._get_vw_train_command(corpus_size, update=True)
 
     def _load_vw_topics(self):
-        """Read topics file generated by Vowpal Wabbit, convert to numpy array.
-
-        Output consists of many header lines, followed by a number of lines
-        of:
-        <word_id> <topic_1_gamma> <topic_2_gamma> ...
-        """
+        """Read topics file generated by Vowpal Wabbit, convert to numpy array."""
         topics = numpy.zeros((self.num_topics, self.num_terms), dtype=numpy.float32)
 
         with utils.smart_open(self._topics_filename) as topics_file:
@@ -430,7 +587,18 @@ class LdaVowpalWabbit(utils.SaveLoad):
     def _predict(self, chunk):
         """Run given chunk of documents against currently trained model.
 
-        Returns a tuple of prediction matrix and Vowpal Wabbit data.
+        Parameters
+        ----------
+        chunk : iterable of list of (int, int)
+            Sequence of documents in BoW format.
+
+        Returns
+        -------
+        predictions : ndarray
+            Tuple of prediction matrix.
+        vw_data : dict
+            Vowpal Wabbit data.
+
         """
         corpus_size = write_corpus_as_vw(chunk, self._corpus_filename)
 
@@ -449,6 +617,23 @@ class LdaVowpalWabbit(utils.SaveLoad):
         return predictions, vw_data
 
     def __getitem__(self, bow, eps=0.01):
+        """Convert document or corpus in BoW format to LDA vectors in BoW format
+
+        Parameters
+        ----------
+        bow : {list of (int, int), iterable of list of (int, int)}
+            Document or corpus in BoW format.
+        eps : float
+            Threshold value (all topics with probability < `eps` will be ignored.
+
+        Returns
+        -------
+        list of (int, float)
+            LDA vector for document **OR**
+        list of list of (int, float)
+            LDA vectors for corpus.
+
+        """
         is_corpus, dummy_corpus = utils.is_corpus(bow)
         if not is_corpus:
             bow = [bow]
@@ -466,51 +651,112 @@ class LdaVowpalWabbit(utils.SaveLoad):
         return topics if is_corpus else topics[0]
 
     def _get_filename(self, name):
-        """Get path to given filename in temp directory."""
+        """Get path to given filename in temp directory.
+
+        Parameters
+        ----------
+        name : str
+            Name of the file.
+
+        Returns
+        -------
+        str
+            Path to a file.
+
+        """
         return os.path.join(self.tmp_dir, name)
 
     @property
     def _model_filename(self):
-        """Get path to file to write Vowpal Wabbit model to."""
+        """Get path to file to write Vowpal Wabbit model to.
+
+        Returns
+        -------
+        str
+            Path to file to write Vowpal Wabbit model to.
+
+        """
         return self._get_filename('model.vw')
 
     @property
     def _cache_filename(self):
-        """Get path to file to write Vowpal Wabbit cache to."""
+        """Get path to file to write Vowpal Wabbit cache to.
+
+        Returns
+        -------
+        str
+            Path to file to write Vowpal Wabbit cache to.
+
+        """
         return self._get_filename('cache.vw')
 
     @property
     def _corpus_filename(self):
-        """Get path to file to write Vowpal Wabbit corpus to."""
+        """Get path to file to write Vowpal Wabbit corpus to.
+
+        Returns
+        -------
+        str
+            Path to file to write Vowpal Wabbit corpus to.
+
+        """
         return self._get_filename('corpus.vw')
 
     @property
     def _topics_filename(self):
-        """Get path to file to write Vowpal Wabbit topics to."""
+        """Get path to file to write Vowpal Wabbit topics to.
+
+        Returns
+        -------
+        str
+            Path to file to write Vowpal Wabbit topics to.
+
+        """
         return self._get_filename('topics.vw')
 
     @property
     def _predict_filename(self):
-        """Get path to file to write Vowpal Wabbit predictions to."""
+        """Get path to file to write Vowpal Wabbit predictions to.
+
+        Returns
+        -------
+        str
+            Path to file to write Vowpal Wabbit predictions to.
+
+        """
         return self._get_filename('predict.vw')
 
     def __str__(self):
+        """Get text representation of model."""
         fields = ['num_terms', 'num_topics', 'chunksize', 'alpha', 'eta']
         kv = ["{0}={1}".format(field, getattr(self, field)) for field in fields]
         return "{0}({1})".format(self.__class__.__name__, ', '.join(kv))
 
 
 def corpus_to_vw(corpus):
-    """Iterate over corpus, yielding lines in Vowpal Wabbit format.
+    """Convert corpus to Vowpal Wabbit format.
 
-    For LDA, this consists of each document on a single line consisting of
-    space separated lists of <word_id>:<count>. Each line starts with a '|'
-    character.
+    Parameters
+    ----------
+    corpus : iterable of list of (int, int)
+        Collection of texts in BoW format.
+
+
+    Notes
+    -----
+
+    Vowpal Wabbit format ::
 
-    E.g.:
         | 4:7 14:1 22:8 6:3
         | 14:22 22:4 0:1 1:3
         | 7:2 8:2
+
+
+    Yields
+    ------
+    str
+        Corpus in Vowpal Wabbit, line by line.
+
     """
     for entries in corpus:
         line = ['|']
@@ -520,9 +766,20 @@ def corpus_to_vw(corpus):
 
 
 def write_corpus_as_vw(corpus, filename):
-    """Iterate over corpus, writing each document as a line to given file.
+    """Covert `corpus` to  Vowpal Wabbit format and save it to `filename`.
+
+    Parameters
+    ----------
+    corpus : iterable of list of (int, int)
+        Collection of texts in BoW format.
+    filename : str
+        Path to output file.
+
+    Returns
+    -------
+    int
+        Number of lines in `filename`.
 
-    Returns the number of lines written.
     """
     logger.debug("Writing corpus to: %s", filename)
 
@@ -538,8 +795,16 @@ def write_corpus_as_vw(corpus, filename):
 def _parse_vw_output(text):
     """Get dict of useful fields from Vowpal Wabbit's output.
 
-    Currently returns field 'average_loss', which is a lower bound on mean
-    per-word log-perplexity (i.e. same as the value LdaModel.bound() returns).
+    Parameters
+    ----------
+    text : str
+        Text from vw file.
+
+    Returns
+    -------
+    dict of (str, float)
+        Dictionary with field "average_loss", lower bound on mean per-word log-perplexity.
+
     """
     data = {}
     for line in text.splitlines():
@@ -551,7 +816,24 @@ def _parse_vw_output(text):
 
 
 def _run_vw_command(cmd):
-    """Execute given Vowpal Wabbit command, log stdout and stderr."""
+    """Execute given Vowpal Wabbit command, log stdout and stderr.
+
+    Parameters
+    ----------
+    cmd : str
+        Given Vowpal Wabbit command to execute.
+
+    Returns
+    -------
+    str
+        Stdout and stderr.
+
+    Raises
+    ------
+    subprocess.CalledProcessError
+        If something goes wrong.
+
+    """
     logger.info("Running Vowpal Wabbit command: %s", ' '.join(cmd))
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
                             stderr=subprocess.STDOUT)
@@ -566,27 +848,47 @@ def _run_vw_command(cmd):
 
 # if python2.6 support is ever dropped, can change to using int.bit_length()
 def _bit_length(num):
-    """Return number of bits needed to encode given number."""
+    """Get number of bits needed to encode given number.
+
+    Parameters
+    ----------
+    num : int
+        Number to encode.
+
+    Returns
+    -------
+    int
+        Number of bits needed to encode given number.
+
+    """
     return len(bin(num).lstrip('-0b'))
 
 
 def vwmodel2ldamodel(vw_model, iterations=50):
-    """
-    Function to convert vowpal wabbit model to gensim LdaModel. This works by
-    simply copying the training model weights (alpha, beta...) from a trained
-    vwmodel into the gensim model.
+    """Convert :class:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit` to
+    :class:`~gensim.models.ldamodel.LdaModel`.
 
-    Args:
-        vw_model : Trained vowpal wabbit model.
-        iterations : Number of iterations to be used for inference of the new LdaModel.
+    This works by simply copying the training model weights (alpha, beta...) from a trained vwmodel
+    into the gensim model.
+
+    Parameters
+    ----------
+    vw_model : :class:`~gensim.models.wrappers.ldavowpalwabbit.LdaVowpalWabbit`
+        Trained Vowpal Wabbit model.
+    iterations : int
+        Number of iterations to be used for inference of the new :class:`~gensim.models.ldamodel.LdaModel`.
+
+    Returns
+    -------
+    :class:`~gensim.models.ldamodel.LdaModel`.
+        Gensim native LDA.
 
-    Returns:
-        model_gensim : LdaModel instance; copied gensim LdaModel.
     """
     model_gensim = LdaModel(
         num_topics=vw_model.num_topics, id2word=vw_model.id2word, chunksize=vw_model.chunksize,
         passes=vw_model.passes, alpha=vw_model.alpha, eta=vw_model.eta, decay=vw_model.decay,
-        offset=vw_model.offset, iterations=iterations, gamma_threshold=vw_model.gamma_threshold
+        offset=vw_model.offset, iterations=iterations, gamma_threshold=vw_model.gamma_threshold,
+        dtype=numpy.float32
     )
     model_gensim.expElogbeta[:] = vw_model._get_topics()
     return model_gensim
