@@ -4,13 +4,12 @@
 # Author: Chinmaya Pancholi <chinmayapancholi13@gmail.com>
 # Copyright (C) 2017 Radim Rehurek <radimrehurek@seznam.cz>
 # Licensed under the GNU LGPL v2.1 - http://www.gnu.org/licenses/lgpl.html
-"""Scikit learn wrapper for gensim.
+"""Scikit-learn wrappers for gensim.
+
 Contains various gensim based implementations which match with scikit-learn standards.
-See [1] for complete set of conventions.
-[1] http://scikit-learn.org/stable/developers/
+See `sklearn dev-guide <http://scikit-learn.org/stable/developers/>`_ for complete set of conventions.
+
 """
-
-
 from .ldamodel import LdaTransformer  # noqa: F401
 from .lsimodel import LsiTransformer  # noqa: F401
 from .rpmodel import RpTransformer  # noqa: F401
