@@ -10,14 +10,9 @@ import logging
 from subprocess import CalledProcessError
 import gensim
 import os
-import sys
 import unittest
 from gensim import corpora
-
-
-# needed because sample data files are located in the same folder
-module_path = os.path.dirname(__file__)
-datapath = lambda fname: os.path.join(module_path, 'test_data', fname)
+from gensim.test.utils import datapath
 
 
 class TestDtmModel(unittest.TestCase):
@@ -28,11 +23,8 @@ class TestDtmModel(unittest.TestCase):
         self.id2word = corpora.Dictionary.load(datapath('dtm_test.dict'))
         # first you need to setup the environment variable $DTM_PATH for the dtm executable file
         self.dtm_path = os.environ.get('DTM_PATH', None)
-        if self.dtm_path is None:
-            if sys.version_info >= (2, 7, 0):
-                self.skipTest("$DTM_PATH is not properly set up.")
-            else:
-                logging.warning("$DTM_PATH is not properly set up.")
+        if not self.dtm_path:
+            self.skipTest("$DTM_PATH is not properly set up.")
 
     def testDtm(self):
         if self.dtm_path is not None:
