@@ -13,6 +13,8 @@ import unittest
 
 import six
 
+import numpy as np
+
 from gensim.utils import to_unicode
 from gensim.models.phrases import SentenceAnalyzer, Phrases, Phraser
 from gensim.models.phrases import pseudocorpus, original_scorer
@@ -148,7 +150,7 @@ class PhrasesData:
 
 
 class PhrasesCommon:
-    """ Tests that need to be run for both Prases and Phraser classes."""
+    """ Tests that need to be run for both Phrases and Phraser classes."""
 
     def setUp(self):
         self.bigram = Phrases(
@@ -230,6 +232,20 @@ class PhrasesCommon:
                 break
         self.assertTrue(bigram1_seen and bigram2_seen)
 
+    def testBigramConstructionFromArray(self):
+        """Test Phrases bigram construction building when corpus is a numpy array"""
+        bigram1_seen = False
+        bigram2_seen = False
+
+        for s in self.bigram[np.array(self.sentences)]:
+            if not bigram1_seen and self.bigram1 in s:
+                bigram1_seen = True
+            if not bigram2_seen and self.bigram2 in s:
+                bigram2_seen = True
+            if bigram1_seen and bigram2_seen:
+                break
+        self.assertTrue(bigram1_seen and bigram2_seen)
+
     def testEncoding(self):
         """Test that both utf8 and unicode input work; output must be unicode."""
         expected = [u'survey', u'user', u'computer', u'system', u'response_time']
