@@ -17,10 +17,10 @@ import numpy
 import scipy
 
 from smart_open import smart_open
-from gensim.corpora import Dictionary
 from gensim.models import word2vec
 from gensim.models import doc2vec
 from gensim.models import KeyedVectors
+from gensim.models import TfidfModel
 from gensim import matutils, similarities
 from gensim.models import Word2Vec, FastText
 from gensim.test.utils import (datapath, get_tmpfile,
@@ -373,8 +373,7 @@ class TestWmdSimilarity(unittest.TestCase, _TestSimilarityABC):
 class TestSoftCosineSimilarity(unittest.TestCase, _TestSimilarityABC):
     def setUp(self):
         self.cls = similarities.SoftCosineSimilarity
-        self.dictionary = Dictionary(texts)
-        self.corpus = [dictionary.doc2bow(document) for document in texts]
+        self.tfidf = TfidfModel(dictionary=dictionary)
         similarity_matrix = scipy.sparse.identity(12, format="lil")
         similarity_matrix[dictionary.token2id["user"], dictionary.token2id["human"]] = 0.5
         similarity_matrix[dictionary.token2id["human"], dictionary.token2id["user"]] = 0.5
@@ -382,33 +381,53 @@ class TestSoftCosineSimilarity(unittest.TestCase, _TestSimilarityABC):
 
     def factoryMethod(self):
         # Override factoryMethod.
-        return self.cls(self.corpus, self.similarity_matrix)
+        return self.cls(corpus, self.similarity_matrix)
 
     def testFull(self, num_best=None):
         # Override testFull.
 
-        index = self.cls(self.corpus, self.similarity_matrix, num_best=num_best)
-        query = self.dictionary.doc2bow(texts[0])
+        # Single query
+        index = self.cls(corpus, self.similarity_matrix, num_best=num_best)
+        query = dictionary.doc2bow(texts[0])
         sims = index[query]
-
         if num_best is not None:
             # Sparse array.
             for i, sim in sims:
                 self.assertTrue(numpy.alltrue(sim <= 1.0))
                 self.assertTrue(numpy.alltrue(sim >= 0.0))
         else:
-            self.assertTrue(sims[0] == 1.0)  # Similarity of a document with itself is 1.0.
+            self.assertAlmostEqual(1.0, sims[0])  # Similarity of a document with itself is 1.0.
             self.assertTrue(numpy.alltrue(sims[1:] >= 0.0))
             self.assertTrue(numpy.alltrue(sims[1:] < 1.0))
             expected = 2.1889350195476758
             self.assertAlmostEqual(expected, numpy.sum(sims))
 
+        # Corpora
+        for query in (
+                corpus,  # Basic text corpus.
+                self.tfidf[corpus]):  # Transformed corpus without slicing support.
+            index = self.cls(query, self.similarity_matrix, num_best=num_best)
+            sims = index[query]
+            if num_best is not None:
+                # Sparse array.
+                for result in sims:
+                    for i, sim in result:
+                        self.assertTrue(numpy.alltrue(sim <= 1.0))
+                        self.assertTrue(numpy.alltrue(sim >= 0.0))
+            else:
+                for i, result in enumerate(sims):
+                    self.assertAlmostEqual(1.0, result[i])  # Similarity of a document with itself is 1.0.
+                    self.assertTrue(numpy.alltrue(result[:i] >= 0.0))
+                    self.assertTrue(numpy.alltrue(result[:i] < 1.0))
+                    self.assertTrue(numpy.alltrue(result[i + 1:] >= 0.0))
+                    self.assertTrue(numpy.alltrue(result[i + 1:] < 1.0))
+
     def testNonIncreasing(self):
         """ Check that similarities are non-increasing when `num_best` is not `None`."""
         # NOTE: this could be implemented for other similarities as well (i.e. in _TestSimilarityABC).
 
-        index = self.cls(self.corpus, self.similarity_matrix, num_best=5)
-        query = self.dictionary.doc2bow(texts[0])
+        index = self.cls(corpus, self.similarity_matrix, num_best=5)
+        query = dictionary.doc2bow(texts[0])
         sims = index[query]
         sims2 = numpy.asarray(sims)[:, 1]  # Just the similarities themselves.
 
@@ -419,8 +438,8 @@ class TestSoftCosineSimilarity(unittest.TestCase, _TestSimilarityABC):
     def testChunking(self):
         # Override testChunking.
 
-        index = self.cls(self.corpus, self.similarity_matrix)
-        query = [self.dictionary.doc2bow(document) for document in texts[:3]]
+        index = self.cls(corpus, self.similarity_matrix)
+        query = [dictionary.doc2bow(document) for document in texts[:3]]
         sims = index[query]
 
         for i in range(3):
@@ -438,7 +457,7 @@ class TestSoftCosineSimilarity(unittest.TestCase, _TestSimilarityABC):
     def testIter(self):
         # Override testIter.
 
-        index = self.cls(self.corpus, self.similarity_matrix)
+        index = self.cls(corpus, self.similarity_matrix)
         for sims in index:
             self.assertTrue(numpy.alltrue(sims >= 0.0))
             self.assertTrue(numpy.alltrue(sims <= 1.0))
