@@ -15,6 +15,7 @@ import numpy as np
 from six import iteritems
 
 from gensim import utils
+from gensim.test.utils import datapath
 
 
 class TestIsCorpus(unittest.TestCase):
@@ -82,7 +83,29 @@ class TestUtils(unittest.TestCase):
         # create a string that fails to decode with unichr on narrow python builds
         body = u'It&#146;s the Year of the Horse. YES VIN DIESEL &#128588; &#128175;'
         expected = u'It\x92s the Year of the Horse. YES VIN DIESEL \U0001f64c \U0001f4af'
-        self.assertEquals(utils.decode_htmlentities(body), expected)
+        self.assertEqual(utils.decode_htmlentities(body), expected)
+
+    def test_open_file_existent_file(self):
+        number_of_lines_in_file = 30
+        with utils.open_file(datapath('testcorpus.mm')) as infile:
+            self.assertEqual(sum(1 for _ in infile), number_of_lines_in_file)
+
+    def test_open_file_non_existent_file(self):
+        with self.assertRaises(Exception):
+            with utils.open_file('non_existent_file.txt'):
+                pass
+
+    def test_open_file_existent_file_object(self):
+        number_of_lines_in_file = 30
+        file_obj = open(datapath('testcorpus.mm'))
+        with utils.open_file(file_obj) as infile:
+            self.assertEqual(sum(1 for _ in infile), number_of_lines_in_file)
+
+    def test_open_file_non_existent_file_object(self):
+        file_obj = None
+        with self.assertRaises(Exception):
+            with utils.open_file(file_obj):
+                pass
 
 
 class TestSampleDict(unittest.TestCase):
@@ -184,12 +207,12 @@ class TestWindowing(unittest.TestCase):
     def test_flatten_nested(self):
         nested_list = [[[1, 2, 3], [4, 5]], 6]
         expected = [1, 2, 3, 4, 5, 6]
-        self.assertEquals(utils.flatten(nested_list), expected)
+        self.assertEqual(utils.flatten(nested_list), expected)
 
     def test_flatten_not_nested(self):
         not_nested = [1, 2, 3, 4, 5, 6]
         expected = [1, 2, 3, 4, 5, 6]
-        self.assertEquals(utils.flatten(not_nested), expected)
+        self.assertEqual(utils.flatten(not_nested), expected)
 
 
 if __name__ == '__main__':
